<?php
declare(strict_types=1);

namespace App\Application\Actions\Images;

use App\Application\Actions\Action;
use Gumlet\ImageResize;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class ProcessorAction extends Action
{
    /**
     * {@inheritdoc}
     */
    protected function action(): Response
    {
        //header("Cache-Control: max-age=2592000");
        $cdnImageSourcePath = $this->getImageFullAbsolutePath(true);
        $cdnAppBasePath = $this->getCdnAppBasePath();
        $cdnLocalFilesPath = $cdnAppBasePath.$cdnImageSourcePath;

        if(!file_exists($cdnLocalFilesPath)){
            $cdnLocalFilesPath = $this->generateLocalImage($cdnLocalFilesPath);
        }

        $image = new ImageResize($cdnLocalFilesPath);
        $image->output(); exit;
    }

    private function generateLocalImage($cdnLocalFilesPath){
        $cdnLocalFilesDirectoryPath = dirname($cdnLocalFilesPath);
        if(!is_dir($cdnLocalFilesDirectoryPath)){
            mkdir($cdnLocalFilesDirectoryPath, 0777, true);
        }
        $imageSourcePath = $this->getImageFullAbsolutePath();
        if(empty($imageSourcePath) || !file_exists($imageSourcePath)){
            echo 'Not found';exit;
        }
        $image = new ImageResize($imageSourcePath);
        $image->resize(1100, 550, true);
        $image->save($cdnLocalFilesPath, IMAGETYPE_WEBP, 80);
        return $cdnLocalFilesPath;
    }



    private function getCdnAppBasePath (){
        $cdnAppBasePath = __DIR__ . '.\\..\\..\\..\\..\\';
        return $cdnAppBasePath;
    }

    private function getOtoAppBasePath (){
        $cdnAppBasePath = $this->getCdnAppBasePath();
        $otoAppBasePath = $cdnAppBasePath.'.\\..\\..\\..\\';
        return $otoAppBasePath;
    }

    private function getImageFullAbsolutePath($forCdn=false){
        $uri =  urldecode($this->request->getUri()->getPath()) ;
        $imageBasename = basename($uri);
        $otoPath = $this->getOtoAppBasePath();
        if(strpos($uri, '/front-images/') !== false){
            $filePath = "backend\\web\\uploads\\front-images\\{$imageBasename}";
            return ($forCdn) ? $filePath : $otoPath.".\\".$filePath;

        }
        if(strpos($uri, '/360images/') !== false){
            $filePath = "backend\\web\\uploads\\360images\\{$imageBasename}";
            return ($forCdn) ? $filePath : $otoPath.".\\".$filePath;
        }
        if(strpos($uri, '/car-listing/') !== false){
            $filePath = "frontend\\web\\uploads\\car-listing\\{$imageBasename}";
            return ($forCdn) ? $filePath : $otoPath.".\\".$filePath;
        }
        return '';
    }
}
