<?php

namespace backend\controllers;

use backend\modules\vehicle\models\search\VehicleSearch;
use backend\modules\vehicle\models\Vehicle;
use backend\modules\vehicle\models\VehicleImages;
use common\helpers\WebpConverter;
use common\models\Images360;
use Yii;
use yii\base\DynamicModel;
use yii\filters\VerbFilter;
use yii\helpers\FileHelper;
use yii\helpers\Json;
use yii\helpers\Url;
use yii\imagine\Image as Imagine;
use yii\web\Controller;
use yii\web\UploadedFile;
use yii2assets\printthis\PrintThis;
use Imagine\Image\Box;
use Imagine\Image\Point;

class CarImagesController extends Controller
{

    public $layout = '@backend/views/layouts/admin/main.php';

    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
        ];
    }

    public function actionIndex()
    {
        $searchModel = new VehicleSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider
        ]);
    }

    public function actionUpload360Images($id)
    {

        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        $vehicle = Vehicle::findOne(['id' => $id]);
        /*$model = Images360::findOne(['id' => 15905]);
        WebpConverter::convert360Image($model);
        die('Call');*/
        $model = new Images360();
        $path = Yii::$app->basePath . '/web/uploads/360images/';
        $counter = $vehicle->image_counter;
        if ($counter == 0) {
            $counter = 1;
        }

        if ($model->load(Yii::$app->request->post())) {

            $model->path = UploadedFile::getInstances($model, 'path');
            if ($model->path) {
                foreach ($model->path as $key => $file) {
                    //$base_path = $vehicle->slug . $vehicle->id . "-webp-($counter)" . '.' . $file->extension;
                    $base_path = $vehicle->slug . $vehicle->id . "($counter)" . '.' . $file->extension;
                    $file->saveAs($path . $base_path);//Upload files to server
                    $model = new Images360();
                    $model->vehicle_id = $vehicle->id;
                    $model->path = $base_path;
                    $model->url = $path . $base_path;
                    $model->extension = $file->extension;
                    $model->size = $file->size;
                    $model->counter = $counter;
                    $model->save(false);

                    $model->removeCdnCache();
                    //$this->Resize($id, $counter);

                    $counter = $counter + 1;
                    $vehicle->image_counter = $counter;
                    $vehicle->stopResettingData = ['saveEquipments'];
                    $vehicle->save(false);

                    //WebpConverter::convert360Image($model);


                }
                return [
                    'id' => md5(time())
                ];
            }
        }

        return [];
    }

    public function actionDeleteUploadedVideo($id){
        $vehicle = Vehicle::findOne(['id' => $id]);
        if(empty($vehicle)){
            Yii::$app->session->setFlash('crudMessage', Yii::t('yii', 'Invalid request to process.'));
            return $this->redirect(Url::to('/vehicle/update/'.$id));
        }

        $directory = Yii::getAlias('@frontend/web/video/vehicles') . DIRECTORY_SEPARATOR;
        if(!empty($vehicle->video_file) && file_exists($directory.$vehicle->video_file)){
            @unlink($directory.$vehicle->video_file);
        }
        $vehicle->video_file = '';
        $vehicle->save(false);
        Yii::$app->session->setFlash('crudMessage', Yii::t('yii', 'Video deleted successfully.'));
        return $this->redirect(Url::to('/vehicle/update/'.$id));
    }

    public function actionUploadVideo($id)
    {
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        $vehicle = Vehicle::findOne(['id' => $id]);
        if(empty($vehicle)){
            return '';
        }
        $oldFile = $vehicle->video_file;
        $videoFile = UploadedFile::getInstance($vehicle, 'video_file');
        $directory = Yii::getAlias('@frontend/web/video/vehicles') . DIRECTORY_SEPARATOR;
        if (!is_dir($directory)) {
            FileHelper::createDirectory($directory);
        }
        if ($videoFile) {
            $uid = uniqid(time(), true);
            $fileName = "{$id}_".$uid . '.' . $videoFile->extension;
            $filePath = $directory . $fileName;
            if ($videoFile->saveAs($filePath)) {
                if(!empty($oldFile) && file_exists($directory.$oldFile)){
                    @unlink($directory.$oldFile);
                }

                $vehicle->video_file = $fileName;
                $vehicle->save(false);
                $path = \Yii::$app->params['frontendUrl'].'/video/vehicles/'. $fileName;
                return [
                    'files' => [
                        [
                            'name' => $fileName,
                            'size' => $videoFile->size,
                            'url' => $path,
                            'thumbnailUrl' => '/images/video-play.png',
                            'deleteUrl' => \yii\helpers\Url::to(['car-images/delete-uploaded-video', 'id' => $id]),
                            'deleteType' => 'GET',
                        ],
                    ],
                ];
            }
        }

        return '';
    }

    public function actionUploadFrontImages($id)
    {
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        $vehicle = Vehicle::findOne(['id' => $id]);

        $front_counter = VehicleImages::find()->where(['vehicle_id' => $id])->count();
        $model = new Images360();
        $path2 = Yii::$app->basePath . '/web/uploads/front-images/';
        $counter = $vehicle->image_counter;
        if ($counter == 0) {
            $counter = 1;
        }

        $width = 265;
        $height = 150;
        $width1 = 380;
        $height1 = 214;

        if ($model->load(Yii::$app->request->post())) {
            $model->path = UploadedFile::getInstances($model, 'path');
            if ($front_counter == 0) {
                $front_counter = 1;
            } else $front_counter++;
            $model->frontImage = UploadedFile::getInstances($model, 'frontImage');
            if ($model->frontImage) {
                foreach ($model->frontImage as $key => $file2) {
                    $base_path = $vehicle->slug . $vehicle->id . '_' . $front_counter . '.' . $file2->extension;
                    $file2->saveAs($path2 . $base_path);//Upload files to server
                    $thumbUrl = $vehicle->slug . $vehicle->id . '_' . $front_counter . '-' . $width . 'x' . $height . '.' . $file2->extension;
                    $thumbUrl2 = $vehicle->slug . $vehicle->id . '_' . $front_counter . '-' . $width1 . 'x' . $height1 . '.' . $file2->extension;

                    if (file_exists($path2 . $base_path)) {
                         Imagine::thumbnail($path2.$base_path, $width, $height)->save($path2.$thumbUrl);
                        //Imagine::thumbnail($path2 . $base_path, $width, $height)
                        //    ->resize(new Box($width, $height))
                        //    ->save($path2 . $thumbUrl);
                         Imagine::thumbnail($path2.$base_path, $width1, $height1)->save($path2.$thumbUrl2);
                        //Imagine::thumbnail($path2 . $base_path, $width1, $height1)
                          //  ->resize(new Box($width1, $height1))
                            //->save($path2 . $thumbUrl2);
                    }
                    //$front_image = VehicleImages::findAll(['vehicle_id'=>$vehicle->id]);
                    //if ($front_image){
                    //    foreach ($front_image as $item) {
                    //        $item->delete();
                    //    }
                    //}
                    $f_image = new VehicleImages();
                    $f_image->vehicle_id = $vehicle->id;
                    $f_image->path = '/uploads/front-images/' . $vehicle->slug . $vehicle->id . '_' . $front_counter;
                    $f_image->extension = $file2->extension;
                    $f_image->type = 'images';
                    $f_image->save();
                    $f_image->removeCdnCache();
                    $front_counter++;
                }
                return [
                    'id' => md5(time())
                ];
            }
        }
        return [];
    }

    public function actionUploadImages($id)
    {
         /*$model = Images360::findOne(['id' => 15905]);
        WebpConverter::convert360Image($model);
        die('Call');*/
        $vehicle = Vehicle::findOne(['id' => $id]);
        $front_image_preview = VehicleImages::findOne(['vehicle_id' => $id]);
        $front_images_all = VehicleImages::findAll(['vehicle_id' => $id]);
        $front_counter = VehicleImages::find()->where(['vehicle_id' => $id])->count();
        $ext = Images360::findOne(['vehicle_id' => $id]);
        $extension = isset($ext->extension) ? $ext->extension : '';
        $count = Images360::find()->where(['vehicle_id' => $id])->count();
        $model = new Images360();
        $image_data = Images360::findAll(['vehicle_id' => $id]);
        $counter = $vehicle->image_counter;
        if ($counter == 0) {
            $counter = 1;
        }

        $width = 265;
        $height = 150;
        $width1 = 380;
        $height1 = 214;


        return $this->render('upload-images', [
            'model' => $model,
            'vehicle' => $vehicle,
            'image_data' => $image_data,
            'id' => $id,
            'count' => $count,
            'extension' => $extension,
            'front_image_preview' => $front_image_preview,
            'front_images_all' => $front_images_all,
            'counter' => $counter
        ]);

    }

    public function actionDeleteAll($id)
    {
        $image = Images360::findAll(['vehicle_id' => $id]);
        $vehicle = Vehicle::findOne(['id' => $id]);
        if(!empty($image)){
            $extension = Images360::findOne(['vehicle_id' => $id]);
            foreach ($image as $key):
                $this->deleteFile($key->path);
                $key->delete();
            endforeach;
            foreach (range(1, 60) as $key) {
                $path = $vehicle->slug . $vehicle->id . "($key)" . '3000x1500.' . $extension->extension;
                $this->deleteFile3000_1500($path);
            }
            foreach (range(1, 60) as $key) {
                $path = $vehicle->slug . $vehicle->id . "($key)" . '1100x550.' . $extension->extension;
                $this->deleteFile1100_550($path);
            }
        }

        $vehicle->image_counter = 0;
        $vehicle->stopResettingData = ['saveEquipments'];
        $vehicle->save(false);
        return $this->redirect(['upload-images', 'id' => $id]);
    }

    public function actionDeleteFrontImage($id)
    {
        $front_image = VehicleImages::findAll(['vehicle_id' => $id]);
        if ($front_image) {
            foreach ($front_image as $item) {
                $item->delete();
                $this->deleteFrontFile($item->path);
            }
        }
        return $this->redirect(['upload-images', 'id' => $id]);
    }

    public function actionGenerateXml($id)
    {
        $vehicle = Images360::findAll(['vehicle_id' => $id]);
        $ext = Images360::findOne(['vehicle_id' => $id]);
        $vehicle2 = Vehicle::findOne(['id' => $id]);
        $path = '/admin.autostudio.jo/uploads/3000x1500';
        $path2 = '/admin.autostudio.jo/uploads/1100x550';

        $counter = $vehicle2->image_counter;
        $count = 0;
        $xmldata = '<?xml version="1.0" encoding="utf-8"?>';
        $xmldata .= '<config>';
        $xmldata .= '<settings>';
        $xmldata .= '<preloader image="' . $path2 . '/' . $vehicle2->slug . $vehicle2->id . '(1)1100x550.' . $ext->extension . '" />';
        $xmldata .= '<userInterface showZoomButtons="true" showToolTips="true" showHotspotsButton="true" showFullScreenButton="true" showTogglePlayButton="true" showArrows="true" toolbarAlign="center" toolbarBackColor="#FFFFFF" toolbarHoverColor="#808285" toolbarForeColor="#A7A9AE" toolbarBackAlpha="0.59" toolbarAlpha="1" showProgressNumbers="true" showFullScreenToolbar="true" fullScreenBackColor="#FFFFFF" />';
        $xmldata .= '<control dragSpeed="0.25" doubleClickZooms="true" disableMouseControl="false" showHighresOnFullScreen="true" mouseHoverDrag="false" hideHotspotsOnLoad="false" hideHotspotsOnZoom="true" rowSensitivity="15" dragSensitivity="10" inBrowserFullScreen="false" doubleClickFullscreen="false" />';
        $xmldata .= '<rotation firstImage="0" rotate="false" rotatePeriod="10" bounce="false" rotateDirection="-1" forceDirection="false" inertiaRelToDragSpeed="true" inertiaTimeToStop="700" inertiaMaxInterval="120" useInertia="true" flipHorizontalInput="false" flipVerticalInput="false" bounceRows="true" />';
        $xmldata .= '</settings>';
        $xmldata .= '<hotspots>';
        $xmldata .= '<hotspot id="spot1" renderMode="0" indicatorImag="circ-cross-thin-blue.svg">';
        $xmldata .= ' <spotinfo txt="Sample hotspot 1" css="font-family:Arial;font-size:14px;color:#333333;width:200px;padding:15px 15px 16px 15px;border:1px solid #E0E0E0;border-radius:4px;background-color:rgba(255,255,255,0.97);" clickAction="5" clickData="play" clickDataParam="2" />';
        $xmldata .= '</hotspot>';
        $xmldata .= '<hotspot id="spot2" renderMode="0" indicatorImag = "circ-cross-thin-green.svg">';
        $xmldata .= '  <spotinfo txt="Sample hotspot 2" css="font-family:Arial;font-size:14px;color:#333333;width:200px;padding:15px 15px 16px 15px;border:1px solid #E0E0E0;border-radius:4px;background-color:rgba(255,255,255,0.97);" clickAction="5" clickData="label2" clickDataParam="2" />';
        $xmldata .= '</hotspot>';
        $xmldata .= ' </hotspots>';
        $xmldata .= '<images rows="1" highresWidth="1566" highresHeight="1032">';
        foreach ($vehicle as $key) {
            $count = $count + 1;
            $xmldata .= '<image src="' . $path2 . '/' . $vehicle2->slug . $vehicle2->id . "($count)" . '1100x550.' . $key->extension . '">';
            $xmldata .= '<hotspot source="spot1" offsetX="138" offsetY="206" />';
            $xmldata .= '<highres src="' . $path . '/' . $vehicle2->slug . $vehicle2->id . "($count)" . '3000x1500.' . $key->extension . '" />';
            $xmldata .= '</image>';

        }
        $xmldata .= '</images>';
        $xmldata .= '</config>';


        if (file_put_contents(Yii::$app->urlManagerFrontEnd->baseUrl . '/web/' . $vehicle2->slug . $vehicle2->id . '.xml', $xmldata)) {
            return $this->redirect(Url::toRoute(['upload-images', 'id' => $id]));
        }

    }

    protected function Resize($id, $counter)
    {
        $vehicle = Images360::findOne(['vehicle_id' => $id]);
        $vehicle2 = Vehicle::findOne(['id' => $id]);
        $path = Yii::$app->basePath . '/web/uploads/360images/';
        $path1 = Yii::$app->basePath . '/web/uploads/1100x550/';
        $path2 = Yii::$app->basePath . '/web/uploads/3000x1500/';

        $width = 1100;
        $height = 550;
        $width1 = 3000;
        $height1 = 1500;

        $base_path = $vehicle2->slug . $vehicle2->id . "($counter)" . '.' . $vehicle->extension;
        $thumbUrl = $vehicle2->slug . $vehicle2->id . "($counter)" . $width . 'x' . $height . '.' . $vehicle->extension;
        $thumbUrl2 = $vehicle2->slug . $vehicle2->id . "($counter)" . $width1 . 'x' . $height1 . '.' . $vehicle->extension;

        if (file_exists($path . $base_path)) {
            Imagine::thumbnail($path . $base_path, $width, $height)
                ->resize(new Box($width, $height))
                ->save($path1 . $thumbUrl);
            //Imagine::thumbnail($path . $base_path, $width, $height)->save($path1 . $thumbUrl);
            //Imagine::thumbnail($path . $base_path, $width1, $height1)->save($path2 . $thumbUrl2);

        }
    }

    public function actionDelete($id)
    {
        $image = Images360::find()->where(['vehicle_id' => $id])->orderBy(['id' => SORT_DESC])->one();
        if ($image) {
            $this->deleteFile($image->path);
            $image->delete();
            $vehicle = Vehicle::findOne(['id' => $id]);
            $vehicle->image_counter = $vehicle->image_counter - 1;
            $vehicle->stopResettingData = ['saveEquipments'];
            $vehicle->save(false);
            return $this->redirect(['upload-images', 'id' => $id]);
        }
        return $this->redirect(['upload-images', 'id' => $id]);

    }

    protected function deleteFile($file)
    {
        $imgpath = Yii::$app->basePath . '/web/uploads/360images/' . $file;
        if (file_exists($imgpath))
            unlink($imgpath);
    }

    protected function deleteFile3000_1500($file)
    {
        $imgpath = Yii::$app->basePath . '/web/uploads/3000x1500/' . $file;
        if (file_exists($imgpath))
            unlink($imgpath);
    }

    protected function deleteFile1100_550($file)
    {
        $imgpath = Yii::$app->basePath . '/web/uploads/1100x550/' . $file;
        if (file_exists($imgpath))
            unlink($imgpath);
    }

    protected function deleteFrontFile($file)
    {
        $imgpath = Yii::$app->basePath . '/web' . $file;
        if (file_exists($imgpath))
            unlink($imgpath);
    }

    public function actionMakeDefaultImage(){
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;

        $defaultImageModel = new DynamicModel(['selectedImage', 'vehicleId']);
        $defaultImageModel->addRule(['selectedImage', 'vehicleId'], 'required');
        if ($defaultImageModel->load(Yii::$app->request->post())) {
            VehicleImages::updateAll(['is_default' => 0], [
                'vehicle_id' => $defaultImageModel->vehicleId
            ]);
            $defaultImage = VehicleImages::findOne($defaultImageModel->selectedImage);
            $defaultImage->is_default = 1;
            $defaultImage->save();
            return [
                'status' => 1,
                'message' => 'Default image marked successfully',
            ];
        }
        return [
            'status' => 0,
            'message' => 'Invalid request',
        ];

    }

    public function actionDeleteSingleFrontImage(){
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;

        $defaultImageModel = new DynamicModel(['selectedImage', 'vehicleId']);
        $defaultImageModel->addRule(['selectedImage', 'vehicleId'], 'required');
        if ($defaultImageModel->load(Yii::$app->request->post())) {
            $image = VehicleImages::findOne($defaultImageModel->selectedImage);
            $image->removeCdnCache();
            $image->delete();
            return [
                'status' => 1,
                'message' => 'Image deleted successfully',
            ];
        }
        return [
            'status' => 0,
            'message' => 'Invalid request',
        ];

    }

}
