<?php

namespace backend\modules\announcement\models;

use common\models\Notifications;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\media\models\Media;
// use yeesoft\models\Users;
use yeesoft\models\User;
use common\models\Users;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;

/**
 * This is the model class for table "announcement".
 *
 * @property int $id
 * @property string $slug
 * @property string $title
 * @property string $breif
 * @property string $content
 * @property int $status 0-pending,1-published
 * @property int $comment_status 0-closed,1-open
 * @property int $publish_on_mobile 0-no,1-yes
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property int $is_campaign
 * @property int $start_date
 * @property int $end_date
 * @property string $view
 * @property string $layout
 * @property string $image
 * @property string $image_header
 * @property string $image_campaign
 */
class Announcement extends ActiveRecord
{
    protected $notificationObject = null;

    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;
    const COMMENT_STATUS_CLOSED = 0;
    const COMMENT_STATUS_OPEN = 1;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'announcement';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%announcement_lang}}",
                'attributes' => [
                    'title', 'brief', 'content',
                ]
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            //[['title', 'content', 'image'], 'required'],
			[['title', 'brief', 'full_name', 'email', 'contact'], 'required'],
            [['created_by', 'updated_by', 'status', 'comment_status', 'publish_on_mobile', 'revision', 'is_campaign'], 'integer'],
            [['title', 'content', 'view', 'layout'], 'string'],
            [['created_at', 'updated_at', 'start_date', 'end_date'], 'safe'],
			[[ 'full_name', 'email', 'contact'], 'string', 'max' => 50],
			[[ 'email'], 'email'],
            [['slug'], 'string', 'max' => 200],
            [['image', 'image_header', 'image_campaign', 'brief'], 'string', 'max' => 255],
            ['published_at', 'date', 'timestampAttribute' => 'published_at', 'format' => 'yyyy-MM-dd'],
            ['published_at', 'default', 'value' => time()],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('auto', 'ID'),
            'slug' => Yii::t('auto', 'Slug'),
            'status' => Yii::t('auto', 'Status'),
            'comment_status' => Yii::t('auto', 'Comment Status'),
            'publish_on_mobile' => Yii::t('auto', 'Publish on Mobile'),
            'published_at' => Yii::t('auto', 'Published At'),
            'created_at' => Yii::t('auto', 'Created At'),
            'updated_at' => Yii::t('auto', 'Updated At'),
            'created_by' => Yii::t('auto', 'Created By'),
            'updated_by' => Yii::t('auto', 'Updated By'),
            'revision' => Yii::t('auto', 'Revision'),
            'view' => Yii::t('auto', 'View'),
            'layout' => Yii::t('auto', 'Layout'),
            'image' => Yii::t('auto', 'Image'),
            'image_header' => Yii::t('auto', 'Header Image'),
            'image_campaign' => Yii::t('auto', 'Campaign Image'),
            'start_date' => Yii::t('auto', 'Start Campaign Date'),
            'end_date' => Yii::t('auto', 'End Campaign Date'),
            'brief' => Yii::t('auto', 'Brief'),
            'title' => Yii::t('auto', 'Title'),
            'full_name' => Yii::t('auto', 'Full Name'),
            'email' => Yii::t('auto', 'Email'),
            'contact' => Yii::t('auto', 'Contact'),

        ];
    }


    public function beforeSave($insert)
    {
        if(!$this->isNewRecord){
            if($this->isAttributeChanged('status') && $this->getAttribute('status') == 1){
                $notification = new Notifications();
                $notification->user_id = null;
                $notification->owner_id = null;
                $notification->type_id = 6;
                $notification->object_id = $this->id;
                $notification->title = 'Announcement';
                $notification->title_ar_ar = 'Announcement';
                $notification->message = 'New announcement has been added';
                $notification->message_ar_ar = 'New announcement has been added';
                $notification->save(false);
            }
        }
        return parent::beforeSave($insert); // TODO: Change the autogenerated stub
    }

    /**
     * {@inheritdoc}
     * @return AnnouncementQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new AnnouncementQuery(get_called_class());
    }



    public function getAuthor()
    {

        return $this->hasOne(Users::className(), ['id' => 'created_by']);
    }

    // public function getUpdatedBy()
    // { 
    //     $d = $this->hasOne(User::className(), ['id' => 'updated_by']);
    //     print_r($d); die;
    // }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getStatusList()[$this->status];
    }

    public function getCommentStatusText()
    {
        return $this->getCommentStatusList()[$this->comment_status];
    }

    public function getRevision()
    {
        return ($this->isNewRecord) ? 1 : $this->revision;
    }

    public function updateRevision()
    {
        $this->updateCounters(['revision' => 1]);
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('yee', 'Pending'),
            self::STATUS_PUBLISHED => Yii::t('yee', 'Published'),
        ];
    }

    /**
     * getStatusOptionsList
     * @return array
     */
    public static function getStatusOptionsList()
    {
        return [
            [self::STATUS_PENDING, Yii::t('yee', 'Pending'), 'default'],
            [self::STATUS_PUBLISHED, Yii::t('yee', 'Published'), 'primary']
        ];
    }

    /**
     * getCommentStatusList
     * @return array
     */
    public static function getCommentStatusList()
    {
        return [
            self::COMMENT_STATUS_OPEN => Yii::t('yee', 'Open'),
            self::COMMENT_STATUS_CLOSED => Yii::t('yee', 'Closed')
        ];
    }

    /**
     * getCommentStatusList
     * @return array
     */
    public static function getPublishOnMobileList()
    {
        return [
            self::COMMENT_STATUS_OPEN => Yii::t('yee', 'Yes'),
            self::COMMENT_STATUS_CLOSED => Yii::t('yee', 'No')
        ];
    }

    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }

    public function getThumbnail($options = ['class' => 'thumbnail pull-left', 'style' => 'width: 240px'])
    {

        if (!empty($this->image)) {
            return Html::img($this->image, $options);
        }

        return;
    }
    /**
     * @return Media
     */
    public function getMediaRefObj($fieldName)
    {
        $imgRefObj = Media::findOne(['url' => $this->$fieldName]);

        return $imgRefObj;
    }


    public function save($runValidation = true, $attributeNames = null){
        \Yii::$app->cache->flush();

        return parent::save($runValidation, $attributeNames);
    }

    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     *
     * @return bool whether the email was sent
     */
    public function sendEmailToNotifyAdmin()
    {

        return Yii::$app->mailer
            ->compose(
                ['html' => 'new-announcement-html', 'text' => 'new-announcement-text'],
                [
                    'model' => $this
                ]
            )
            ->setTo(Yii::$app->params['senderEmail'])
            ->setFrom([Yii::$app->params['senderEmail'] => Yii::$app->params['senderName']])
            ->setSubject('New Announcement Listed ' . Yii::$app->name)
            ->send();
    }

}
