<?php

namespace backend\modules\bms\models;

use Yii;
use backend\modules\career\models\RecruitmentGuidanceBms;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\models\User;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;
use yii\helpers\Url;

/**
 * This is the model class for table "news".
 *
 * @property int $id
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property string $url
 * @property string $image
 * @property string $category
 */
class Bms extends ActiveRecord
{

    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'bms';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%bms_lang}}",
                'attributes' => [
                    'title', 'second_title', 'brief', 'button_text', 'image',
                ]
            ],
        ];
    }


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['title', 'category','status'], 'required'],
            [['created_by', 'updated_by'], 'integer'],
            [['title',  'button_text'], 'string', 'max' => 255],
            [['url', 'image'], 'string', 'max' => 255],
            [['created_at', 'updated_at'], 'safe'],
            [['brief', 'second_title'], 'string'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'slug' => Yii::t('site', 'Slug'),
            'status' => Yii::t('site', 'Status'),
            'comment_status' => Yii::t('site', 'Comment Status'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
            'image' => Yii::t('site', 'Image'),
            'image_header' => Yii::t('site', 'BMS'),
            'start_date' => Yii::t('site', 'Start Campaign Date'),
            'end_date' => Yii::t('site', 'End Campaign Date'),

        ];
    }

    /**
     * {@inheritdoc}
     * @return BmsQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new BmsQuery(get_called_class());
    }



    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('site', 'Pending'),
            self::STATUS_PUBLISHED => Yii::t('site', 'Published'),
        ];
    }


    /**
     * getTypeList
     * @return array
     */
    public static function getCategoryList()
    {
        return [
            '' => Yii::t('site', ''),
            'HomePageTop' => Yii::t('site', 'HomePageTop'),
            'FooterBanner' => Yii::t('site', 'FooterBanner'),
            'WhoWeAreBanner' => Yii::t('site', 'WhoWeAreBanner'),
            'CarCategoryBannerHomePage' => Yii::t('site', 'CarCategoryBannerHomePage'),
//            'diagnosisBanner' => Yii::t('site', 'diagnosisBanner'),
//            'saveLivesBanner' => Yii::t('site', 'saveLivesBanner'),
//            'HomePageBlocks' => Yii::t('site', 'HomePageBlocks'),
        ];
    }


    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }

    public function getThumbnail($options = ['class' => 'thumbnail pull-left', 'style' => 'width: 240px'])
    {

        if (!empty($this->image)) {
            return Html::img($this->image, $options);
        }

        return;
    }


    /**
     * @return \yii\db\ActiveQuery
     */
    public function getGuidanceBms()
    {
        return $this->hasOne(RecruitmentGuidanceBms::className(), ['bms_id' => 'id']);
    }


    public function getUrl(){
        $url = parse_url($this->url);
        if (isset($url['fragment'])) {
            $this->url = Yii::$app->request->url . $this->url;
        } 

        $this->url = Url::to([$this->url]);
        if (isset($_GET['language'])) {
            $this->url = preg_replace('/&?language=[^&]*/', '', $this->url);
            $this->url = rtrim($this->url,'?');
        }

        if (substr( $this->url, 0, 6 ) == "/site/") {
            $this->url =  '/' . Yii::$app->language . str_ireplace('site/', '', $this->url);
        }
        
        return $this->url;
    }
}
