<?php

namespace backend\modules\career\models;

use backend\modules\bms\models\Bms;
use common\helpers\Utility;
use common\models\User;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "recruitment_guidance".
 *
 * @property int $id
 * @property string $slug
 * @property int $status 0-pending,1-published
 * @property string $image_header
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 */
class RecruitmentGuidance extends ActiveRecord
{
    public $features;


    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'recruitment_guidance';
    }


    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%recruitment_guidance_lang}}",
                'attributes' => [
                    'title', 'content',
                    'sub_title', 'sub_content',
                    'feature_title', 'feature_content',
                ]
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['title', 'content'], 'required'],
            [['created_by', 'updated_by', 'status', 'revision'], 'integer'],
            [['content', 'view', 'layout', 'sub_content'], 'string'],
            [['created_at', 'updated_at'], 'safe'],
            [['slug'], 'string', 'max' => 200],
            [['image_header', 'title', 'sub_title','feature_title', 'feature_content','image_sub'], 'string', 'max' => 255],
            ['slug', 'unique'],
            ['published_at', 'date', 'timestampAttribute' => 'published_at', 'format' => 'yyyy-MM-dd'],
            ['published_at', 'default', 'value' => time()],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'slug' => Yii::t('site', 'Slug'),
            'status' => Yii::t('site', 'Status'),
            'title' => Yii::t('site', 'Main Title'),
            'content' => Yii::t('site', 'Main Brief'),
            'image_header' => Yii::t('site', 'Image Header'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
        ];
    }

    /**
     * {@inheritdoc}
     * @return RecruitmentGuidanceQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new RecruitmentGuidanceQuery(get_called_class());
    }


    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getStatusList()[$this->status];
    }

    public function getCommentStatusText()
    {
        return $this->getCommentStatusList()[$this->comment_status];
    }

    public function getRevision()
    {
        return ($this->isNewRecord) ? 1 : $this->revision;
    }

    public function updateRevision()
    {
        $this->updateCounters(['revision' => 1]);
    }



    /**
     * @return \yii\db\ActiveQuery
     */
    public function getBmss()
    {
        return $this->hasMany(RecruitmentGuidanceBms::className(), ['guidance_id' => 'id'])->innerJoinWith('bms')->where(['status' => Utility::STATUS_PUBLISHED, 'category' => 'GuidanceFeature']);
    }

    public function save($runValidation = true, $attributeNames = null)
    {
        \Yii::$app->cache->flush();
        return parent::save($runValidation, $attributeNames);
    }

}
