<?php

namespace backend\modules\career\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use common\helpers\Utility;
use common\models\User;
use Yii;
use yii\behaviors\TimestampBehavior;
use yii\data\ActiveDataProvider;
use yii\web\UploadedFile;

/**
 * This is the model class for table "user_vacancy".
 *
 * @property int $id
 * @property int $user_id
 * @property string $name
 * @property string $email
 * @property string $phone
 * @property string $gender
 * @property string $date_of_birth
 * @property string $cv_file
 * @property int $vacancy_id
 * @property string $interview_date
 * @property string $status
 * @property int $created_at
 * @property int $viewed
 *
 * @property User $user
 * @property Vacancy $vacancy
 */
class UserVacancy extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'user_vacancy';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date_of_birth'], 'safe'],
            [['email'], 'email'],
            [['status', 'created_at', 'updated_at'], 'integer'],
            [['name', 'email', 'phone', 'gender', 'cv_file'], 'string', 'max' => 255],
            [['name', 'email', 'phone', 'gender', 'cv_file', 'date_of_birth'], 'required'],
            [['cv_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'pdf'],
            [['vacancy_id'], 'required'],
            [['interview_date'], 'safe'],
            [['status'], 'string'],
            [['user_id', 'vacancy_id', 'created_at', 'viewed'], 'integer'],
//            [['user_id', 'vacancy_id'], 'unique', 'targetAttribute' => ['user_id', 'vacancy_id']],
//            [['vacancy_id', 'user_id'], 'unique', 'targetAttribute' => ['vacancy_id', 'user_id']],
            [['user_id'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['user_id' => 'id']],
            [['vacancy_id'], 'exist', 'skipOnError' => true, 'targetClass' => Vacancy::className(), 'targetAttribute' => ['vacancy_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [

            'AuditTrail' => [
                'class' => AuditTrailBehavior::className(),
            ],
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'updatedAtAttribute' => false,
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'user_id' => Yii::t('site', 'User'),
            'vacancy_id' => Yii::t('site', 'Vacancy'),
            'created_at' => Yii::t('site', 'Created At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUser()
    {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVacancy()
    {
        return $this->hasOne(Vacancy::className(), ['id' => 'vacancy_id']);
    }

    public function getReadableStatus()
    {
        return Utility::getAppliedJobStatusList()[$this->status];
    }

    public function updateInterview($date)
    {
        $this->interview_date = $date;
        if(Yii::$app->user->id == $this->user_id)//User Change
            $this->status = 'WAITING_ADMIN_APPROVAL';
        else//Admin Change
            $this->status = 'INTERVIEW';

        if ($this->save()) {

            //Send Email
            Yii::$app->mailer->compose()
                ->setTo($this->user->email)
                ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
                ->setSubject('Interview - ' . $this->vacancy->title)
                ->setTextBody('')
                ->send();
        }
    }


    public function uploadFiles()
    {
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/cv', // Path for uploaded files in web directory
        ];
        try {
            $file1 = UploadedFile::getInstance(new self(), "cv_file");
            $media1 = Utility::saveUploadedFile($file1, $routes);
            //$this->familyBookFile = $media1->file;
            $this->cv_file = $media1->url;
        } catch (\Exception $e) {
        }

    }

    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     * @param  string $email the target email address
     * @return boolean whether the email was sent
     */
    public function sendEmail($email)
    {
        $body = Yii::$app->controller->renderPartial('@backend/modules/career/views/mail/career', ['model' => $this]);

        return Yii::$app->mailer->compose()
            ->setTo($email)
            ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
            ->setReplyTo([$this->email => $this->name])
            ->setSubject('Careers Request From ' . $this->name . ' <' . $this->email . '>')
            ->attach(Yii::getAlias('@frontend') . '/web' . $this->cv_file)
            ->setHtmlBody($body)
            ->send();
    }
    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = UserVacancy::find();

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
//            'sort' => [
//                'defaultOrder' => [
//                    'id' => SORT_DESC,
//                ],
//            ],
        ]);

        $this->load($params);

        $query->andFilterWhere([
           'vacancy_id' => $this->vacancy_id,
           'user_id' => $this->user_id,
           'status' => $this->status,
           'viewed' => $this->viewed,
        ]);

//        var_dump($query->createCommand()->rawSql);
        return $dataProvider;
    }
}
