<?php

use wbraganca\dynamicform\DynamicFormWidget;
use yeesoft\widgets\ActiveForm;
use yii\helpers\Html;

use yeesoft\models\User;
use backend\modules\bms\models\Bms;
use yii\jui\DatePicker;


/* @var $this yii\web\View */
/* @var $model backend\modules\career\models\RecruitmentGuidance */

$this->title = 'Create Feature';
$this->params['breadcrumbs'][] = ['label' => 'Recruitment Guidances', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="recruitment-guidance-create">
    <h3 class="lte-hide-title"><?= Html::encode($this->title) ?></h3>


    <div class="page-form">

        <?php
        $form = ActiveForm::begin([
            'id' => 'page-form',
            'validateOnBlur' => true,
        ]);
        echo Html::hiddenInput('guidance_id', $guidance_id);

        echo Html::activeHiddenInput($bmsModel, 'id');

        ?>

        <div class="row">
            <div class="col-md-9">

                <div class="panel panel-default">
                    <div class="panel-body">

                        <?php if ($bmsModel->isMultilingual()): ?>
                            <?= \yeesoft\widgets\LanguagePills::widget() ?>
                        <?php endif; ?>

                        <?= $form->field($bmsModel, 'title')->textInput(['maxlength' => true]) ?>
                        <?= $form->field($bmsModel, 'brief')->textInput(['maxlength' => true]) ?>
                        <?= $form->field($bmsModel, 'button_text')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($bmsModel, 'image')->widget(yeesoft\media\widgets\FileInput::className(), [
                            'name' => 'image',
                            'buttonTag' => 'button',
                            'buttonName' => Yii::t('site', 'Browse'),
                            'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                            'options' => ['class' => 'form-control'],
                            'template' => '<div class="bms-image thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                            //'thumb' => $this->context->module->thumbnailSize,
                            'imageContainer' => '.bms-image',
                            'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                            'callbackBeforeInsert' => 'function(e, data) {
                                $(".bms-image").show();
                            }',
                        ]) ?>

                    </div>
                </div>
            </div>

            <div class="col-md-3">

                <div class="panel panel-default">
                    <div class="panel-body">
                        <div class="record-info">
                            <div class="form-group">
                                <?php if ($bmsModel->isNewRecord): ?>
                                    <?= Html::submitButton(Yii::t('site', 'Create'), ['class' => 'btn btn-primary']) ?>
                                    <?= Html::a(Yii::t('site', 'Cancel'), ['/bms/default/index'], ['class' => 'btn btn-default',]) ?>
                                <?php else: ?>
                                    <?= Html::submitButton(Yii::t('site', 'Save'), ['class' => 'btn btn-primary']) ?>
                                    <?=
                                    Html::a(Yii::t('site', 'Delete'), ['/bms/default/delete', 'id' => $bmsModel->id], [
                                        'class' => 'btn btn-default',
                                        'data' => [
                                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                            'method' => 'post',
                                        ],
                                    ])
                                    ?>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="panel panel-default">
                    <div class="panel-body">

                        <div class="record-info">
                            <?= $form->field($bmsModel, 'url')->textInput(['maxlength' => true]) ?>

                            <?=
                            $form->field($bmsModel, 'published_at')
                                ->widget(DatePicker::className(), ['dateFormat' => 'yyyy-MM-dd', 'options' => ['class' => 'form-control']]);
                            ?>

                            <?=
                            $form->field($bmsModel, 'category')->dropDownList([
                                'GuidanceFeature' => Yii::t('site', 'GuidanceFeature'),
                            ])
                            ?>
                            <?=
                            $form->field($bmsModel, 'status')->dropDownList(Bms::getStatusList())
                            ?>

                            <?php if (!$bmsModel->isNewRecord): ?>
                                <?= $form->field($bmsModel, 'created_by')->dropDownList(User::getUsersList()) ?>
                            <?php endif; ?>

                        </div>
                    </div>
                </div>


            </div>
        </div>

        <?php ActiveForm::end(); ?>

    </div>


    <?php


    $js = <<<JS
    var image = $("#bms-image").val();
    if(image.length == 0){
        $('.bms-image').hide();
    } else {
        $('.bms-image').html('<img src="' + image + '" />');
    }
    
JS;

    $this->registerJs($js, yii\web\View::POS_END);
    ?>


</div>