<?php

use backend\modules\bms\models\Bms;
use common\models\User;
use wbraganca\dynamicform\DynamicFormWidget;
use yeesoft\grid\GridPageSize;
use yeesoft\grid\GridView;
use yeesoft\widgets\ActiveForm;
use yii\helpers\Url;
use yii\widgets\DetailView;
use yeesoft\helpers\Html;
use yii\widgets\Pjax;
use yii\jui\DatePicker;

/* @var $this yii\web\View */
/* @var $model backend\modules\career\models\RecruitmentGuidance */

$this->title = $model->title;
$this->params['breadcrumbs'][] = ['label' => 'Recruitment Guidances', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="recruitment-guidance-view">

    <h3 class="lte-hide-title"><?= Html::encode($this->title) ?></h3>

    <div class="panel panel-default">
        <div class="panel-body">

            <p>
                <?= Html::a('Edit', ['/career/guidance/update', 'id' => $model->id],
                    ['class' => 'btn btn-sm btn-primary'])
                ?>
                <?= Html::a('Delete', ['/career/guidance/delete', 'id' => $model->id],
                    [
                        'class' => 'btn btn-sm btn-default',
                        'data' => [
                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                            'method' => 'post',
                        ],
                    ])
                ?>



                <?= Html::a(Yii::t('yee', 'Add New'), ['/career/guidance/create'],
                    ['class' => 'btn btn-sm btn-primary pull-right'])
                ?>
            </p>


            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    'slug',
                    'status',
                    'image_header',
                    'published_at',
                    'created_at',
                    'updated_at',
                    'created_by',
                    'updated_by',
                    'revision',
                    'view',
                    'layout',
                ],
            ])
            ?>

        </div>
    </div>


    <div class="panel panel-default">
        <div class="panel-heading">
            <span class="panel-title"><?= Yii::t('app', 'Feature(s)') ?></span>
            <div class="pull-right ">
                <?= Html::a('Add New Feature', ['/career/guidance/create-feature', 'id' => $model->id],
                    ['class' => 'btn btn-sm btn-success '])
                ?>
            </div>
        </div>
        <div class="panel-body">

            <?php Pjax::begin(['id' => 'page-grid-pjax']) ?>

            <?php
            try {
                echo GridView::widget([
                    'id' => 'page-grid',
                    'dataProvider' => $bmsDataProvider,
//                    'filterModel' => $searchModel,
                    'bulkActionOptions' => [
                        'gridId' => 'page-grid',
                        'actions' => [
//                            Url::to(['bulk-activate']) => Yii::t('site', 'Publish'),
//                            Url::to(['bulk-deactivate']) => Yii::t('site', 'Unpublish'),
                            Url::to(['bulk-delete']) => Yii::t('yii', 'Delete'),
                        ]
                    ],
                    'columns' => [
                        ['class' => 'yeesoft\grid\CheckboxColumn', 'options' => ['style' => 'width:10px']],
                        [
                            'class' => 'yeesoft\grid\columns\TitleActionColumn',
                            'controller' => '/career/guidance',
                            'title' => function (Bms $model) {
                                return Html::a($model->title, ['/bms/default/view', 'id' => $model->id], ['data-pjax' => 0]);
                            },
                            'buttons' =>
                                [
                                    'view' => function ($url, $model, $key) {
                                        return '';
                                    },
                                    'update' => function ($url, $itemModel, $key) use ($model) {
                                        return Html::a('Update', ['/career/guidance/update-feature', 'id' => $itemModel->id, 'guidance_id' => $model->id], ['data-pjax' => '0',]);
                                    },
                                    'delete' => function ($url, $itemModel, $key) use ($model) {
                                        return Html::a('Delete', ['/career/guidance/delete-feature', 'id' => $itemModel->id, 'guidance_id' => $model->id]);
                                    },
                                ],
                        ],
                        [
                            'attribute' => 'status',
                        ]
//                        [
//                            'attribute' => 'created_by',
//                            'filter' => User::getUsersList(),
//                            'value' => function (Bms $model) {
//                                return Html::a($model->author->username,
//                                    ['/user/default/update', 'id' => $model->created_by],
//                                    ['data-pjax' => 0]);
//                            },
//                            'format' => 'raw',
//                            'visible' => User::hasPermission('viewUsers'),
//                            'options' => ['style' => 'width:180px'],
//                        ],
                    ],
                ]);
            } catch (Exception $e) {
            }
            ?>

            <?php Pjax::end() ?>
        </div>
    </div>


    <div class="panel panel-default">
        <div class="panel-heading">
            <span class="panel-title"><?= Yii::t('app', 'Footer Banner') ?></span>
            <div class="pull-right ">
                <?= Html::a('Add New', ['/career/guidance/create-feature', 'id' => $model->id],
                    ['class' => 'btn btn-sm btn-success '])
                ?>
            </div>
        </div>
        <div class="panel-body">

            <?php
            $form = ActiveForm::begin([
                'id' => 'page-form',
                'validateOnBlur' => true,
            ]);
            echo Html::hiddenInput('Bms[guidance_id]', $model->id);

            ?>

            <div class="row">
                <div class="col-md-9">

                    <div class="panel panel-default">
                        <div class="panel-body">

                            <?php if ($footerBms->isMultilingual()): ?>
                                <?= \yeesoft\widgets\LanguagePills::widget() ?>
                            <?php endif; ?>

                            <?= $form->field($footerBms, 'title')->textInput(['maxlength' => true]) ?>
                            <?= $form->field($footerBms, 'brief')->textInput(['maxlength' => true]) ?>
                            <?= $form->field($footerBms, 'button_text')->textInput(['maxlength' => true]) ?>

                            <?= $form->field($footerBms, 'image')->widget(yeesoft\media\widgets\FileInput::className(), [
                                'name' => 'image',
                                'buttonTag' => 'button',
                                'buttonName' => Yii::t('site', 'Browse'),
                                'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                                'options' => ['class' => 'form-control'],
                                'template' => '<div class="bms-image thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                                //'thumb' => $this->context->module->thumbnailSize,
                                'imageContainer' => '.bms-image',
                                'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                                'callbackBeforeInsert' => 'function(e, data) {
                                $(".bms-image").show();
                            }',
                            ]) ?>

                        </div>
                    </div>
                </div>

                <div class="col-md-3">

                    <div class="panel panel-default">
                        <div class="panel-body">
                            <div class="record-info">
                                <div class="form-group">
                                    <?php if ($footerBms->isNewRecord): ?>
                                        <?= Html::submitButton(Yii::t('site', 'Create'), ['class' => 'btn btn-primary']) ?>
                                        <?= Html::a(Yii::t('site', 'Cancel'), ['/bms/default/index'], ['class' => 'btn btn-default',]) ?>
                                    <?php else: ?>
                                        <?= Html::activeHiddenInput($footerBms, 'id'); ?>

                                        <?= Html::submitButton(Yii::t('site', 'Save'), ['class' => 'btn btn-primary']) ?>
                                        <?=
                                        Html::a(Yii::t('site', 'Delete'), ['/bms/default/delete', 'id' => $footerBms->id], [
                                            'class' => 'btn btn-default',
                                            'data' => [
                                                'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                                'method' => 'post',
                                            ],
                                        ])
                                        ?>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="panel panel-default">
                        <div class="panel-body">

                            <div class="record-info">
                                <?= $form->field($footerBms, 'url')->textInput(['maxlength' => true]) ?>

                                <?=
                                $form->field($footerBms, 'published_at')
                                    ->widget(DatePicker::className(), ['dateFormat' => 'yyyy-MM-dd', 'options' => ['class' => 'form-control']]);
                                ?>

                                <?=
                                $form->field($footerBms, 'category')->dropDownList([
                                    'RecruitmentGuidance' => Yii::t('site', 'RecruitmentGuidance'),
                                ])
                                ?>
                                <?=
                                $form->field($footerBms, 'status')->dropDownList(Bms::getStatusList())
                                ?>

                                <?php if (!$footerBms->isNewRecord): ?>
                                    <?= $form->field($footerBms, 'created_by')->dropDownList(User::getUsersList()) ?>
                                <?php endif; ?>

                            </div>
                        </div>
                    </div>


                </div>
            </div>

            <?php ActiveForm::end(); ?>

        </div>
    </div>
</div>

</div>


<?php


$js = <<<JS
    var image = $("#bms-image").val();
    if(image.length == 0){
        $('.bms-image').hide();
    } else {
        $('.bms-image').html('<img src="' + image + '" />');
    }
    
JS;

$this->registerJs($js, yii\web\View::POS_END);
?>


</div>