<?php

namespace backend\modules\doctor_questionnaire\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use common\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "doctor_questionnaire".
 *
 * @property int $id
 * @property string $name
 * @property int $doctor_speciality_id Dropdown Menu - JobTileField
 * @property int $has_number_of_cases
 * @property int $status 0-pending,1-published
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 *
 * @property DoctorQuestionnaireItem[] $doctorQuestionnaireItems
 */
class DoctorQuestionnaire extends \yii\db\ActiveRecord
{
    public $questionItems;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'doctor_questionnaire';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['name', 'doctor_speciality_id'], 'required'],
            [['doctor_speciality_id', 'has_number_of_cases', 'status', 'published_at', 'created_at', 'updated_at', 'created_by', 'updated_by', 'revision'], 'integer'],
            [['name', 'view', 'layout'], 'string', 'max' => 255],
        ];
    }

    /**
     * @inheritdoc
     */
    public function init()
    {
        parent::init();

        $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveQuestions']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveQuestions']);
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            TimestampBehavior::className(),
            BlameableBehavior::className(),
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'name' => Yii::t('site', 'Name'),
            'doctor_speciality_id' => Yii::t('site', 'Doctor Speciality ID'),
            'has_number_of_cases' => Yii::t('site', 'Has Number Of Cases'),
            'status' => Yii::t('site', 'Status'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
        ];
    }


    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }


    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDoctorQuestionnaireItems()
    {
        return $this->hasMany(DoctorQuestionnaireItem::className(), ['parent_id' => 'id'])->multilingual();
    }

    /**
     * {@inheritdoc}
     * @return DoctorQuestionnaireQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new DoctorQuestionnaireQuery(get_called_class());
    }


    /**
     * Handle save tags event of the owner.
     */
    public function saveQuestions()
    {
        $lng = Yii::$app->language;
        /** @var DoctorQuestionnaire $owner */
        $owner = $this->owner;

        $questionItems = Yii::$app->getRequest()->post('DoctorQuestionnaireItem');
//        var_dump($questionItems);die();
        if (is_array($questionItems)) {
            DoctorQuestionnaireItem::deleteAll(['parent_id' => $owner->id]);
            foreach ($questionItems as $questionItem) {
                $obj = new DoctorQuestionnaireItem();
                $obj->parent_id = $owner->id;
                $questionItem['title'] = $questionItem["q_" . $lng];
                $questionItem['title_ar'] = $questionItem["q_ar"];


                $obj->load(['DoctorQuestionnaireItem' => $questionItem], 'DoctorQuestionnaireItem');
                if(!$obj->save()){
                    var_dump($obj->getErrors());die();
                }
            }
        }
    }

}
