<?php

namespace backend\modules\general_question\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "general_question_item".
 *
 * @property int $id
 * @property int $parent_id
 * @property string $slug
 * @property string $correct_answer
 * @property int $status 0-pending,1-published
 * @property string $url
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 *
 * @property GeneralQuestion $parent
 */
class GeneralQuestionItem extends ActiveRecord
{
    //Use it on Admin Form
    public $q_en, $q_ar;

    //Use it on User Form
    public $questions;
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'general_question_item';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['parent_id', 'status', 'published_at', 'created_at', 'updated_at', 'created_by', 'updated_by', 'revision'], 'integer'],
            [['title', 'correct_answer'], 'required'],
            [['questions'], 'required', 'on' => 'JobApply'],
            [['correct_answer'], 'string'],
            [['slug', 'url', 'view', 'layout'], 'string', 'max' => 255],
            [['q_en', 'q_ar'], 'string', 'max' => 255],
            [['q_en', 'q_ar'], 'required'],
            [['parent_id'], 'exist', 'skipOnError' => true, 'targetClass' => GeneralQuestion::className(), 'targetAttribute' => ['parent_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%general_question_item_lang}}",
                'attributes' => [
                    'title'
                ]
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'parent_id' => Yii::t('site', 'Parent ID'),
            'slug' => Yii::t('site', 'Slug'),
            'correct_answer' => Yii::t('site', 'Correct Answer'),
            'status' => Yii::t('site', 'Status'),
            'url' => Yii::t('site', 'Url'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
        ];
    }


    /**
     * {@inheritdoc}
     * @return GeneralQuestionItemQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new GeneralQuestionItemQuery(get_called_class());
    }


    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParent()
    {
        return $this->hasOne(GeneralQuestion::className(), ['id' => 'parent_id']);
    }

}
