<?php

namespace backend\modules\network\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\models\User;
use Yii;
use yeesoft\db\ActiveRecord;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;


/**
 * This is the model class for table "network".
 *
 * @property int $id
 * @property string $phone
 * @property string $fax
 * @property string $email
 * @property int $status 0-pending,1-published
 * @property string $latitude
 * @property string $longitude
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 *
 *  * @property Category $category
 *
 */
class Network extends ActiveRecord
{

    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;
    const COMMENT_STATUS_CLOSED = 0;
    const COMMENT_STATUS_OPEN = 1;


    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'network';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
//            AuditTrailBehavior::className(),
//            TimestampBehavior::className(),
//            BlameableBehavior::className(),
           /* 'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'name',
            ],*/
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%network_lang}}",
                'attributes' => [
                    'name', 'district', 'sub_district', 'city', 'complex_name', 'category'
                ]
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['name'], 'required'],
            [['created_by', 'updated_by', 'status', 'revision'], 'integer'],
            [['view', 'layout', 'city'], 'string'],
            [['created_at', 'updated_at'], 'safe'],
            [['phone', 'fax', 'name'], 'string', 'max' => 200],
            ['published_at', 'date', 'timestampAttribute' => 'published_at', 'format' => 'yyyy-MM-dd'],
            ['published_at', 'default', 'value' => time()],
            [['latitude', 'longitude'], 'number'],
            [['email', ], 'email'],

        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'phone' => Yii::t('site', 'Phone'),
            'name' => Yii::t('site', 'Name'),
            'address' => Yii::t('site', 'Address'),
            'category' => Yii::t('site', 'Category'),
            'fax' => Yii::t('site', 'Fax'),
            'email' => Yii::t('site', 'Email'),
            'status' => Yii::t('site', 'Status'),
            'city' => Yii::t('site', 'City'),
            'latitude' => Yii::t('site', 'Latitude'),
            'longitude' => Yii::t('site', 'Longitude'),
            'category_id' => Yii::t('site', 'Category'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
        ];
    }


    /**
     * {@inheritdoc}
     * @return NetworkQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new NetworkQuery(get_called_class());
    }



//    /**
//     * @return \yii\db\ActiveQuery
//     */
//    public function getCategory()
//    {
//        return $this->hasOne(Category::className(), ['id' => 'category_id']);
//    }


    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getStatusList()[$this->status];
    }


    public function getRevision()
    {
        return ($this->isNewRecord) ? 1 : $this->revision;
    }

    public function updateRevision()
    {
        $this->updateCounters(['revision' => 1]);
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('yee', 'Pending'),
            self::STATUS_PUBLISHED => Yii::t('yee', 'Published'),
        ];
    }

    /**
     * getStatusOptionsList
     * @return array
     */
    public static function getStatusOptionsList()
    {
        return [
            [self::STATUS_PENDING, Yii::t('yee', 'Pending'), 'default'],
            [self::STATUS_PUBLISHED, Yii::t('yee', 'Published'), 'primary']
        ];
    }

    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullNetworkAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }

}
