<?php

namespace backend\modules\places\models;

use Yii;

/**
 * This is the model class for table "filter".
 *
 * @property int $id
 * @property int $group_id
 * @property string $name_en
 * @property string $name_ar
 * @property int $is_service
 * @property int $is_product
 * @property int $is_searchable
 * @property string $created
 * @property string $updated
 * @property string $isic_class_code
 *
 * @property Group $group
 * @property PlaceFilter[] $placeFilters
 * @property Places[] $places
 */
class Filter extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'filter';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['group_id', 'is_service', 'is_product', 'is_searchable'], 'integer'],
            [['name_en', 'created', 'updated'], 'required'],
            [['created', 'updated'], 'safe'],
            [['name_en', 'name_ar', 'isic_class_code'], 'string', 'max' => 255],
            [['group_id'], 'exist', 'skipOnError' => true, 'targetClass' => Group::className(), 'targetAttribute' => ['group_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'group_id' => Yii::t('site', 'Group ID'),
            'name_en' => Yii::t('site', 'Name En'),
            'name_ar' => Yii::t('site', 'Name Ar'),
            'is_service' => Yii::t('site', 'Is Service'),
            'is_product' => Yii::t('site', 'Is Product'),
            'is_searchable' => Yii::t('site', 'Is Searchable'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
            'isic_class_code' => Yii::t('site', 'Isic Class Code'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getGroup()
    {
        return $this->hasOne(Group::className(), ['id' => 'group_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlaceFilters()
    {
        return $this->hasMany(PlaceFilter::className(), ['filter_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlaces()
    {
        return $this->hasMany(Places::className(), ['id' => 'place_id'])->viaTable('place_filter', ['filter_id' => 'id']);
    }

    /**
     * {@inheritdoc}
     * @return FilterQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new FilterQuery(get_called_class());
    }
}
