<?php

namespace backend\modules\product\models;

use common\helpers\Utility;
use common\models\User;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "sub_product".
 *
 * @property int $id
 * @property int $parent_id
 * @property string $slug
 * @property string $image
 * @property string $image_header
 * @property string $icon_1
 * @property string $icon_2
 * @property string $icon_3
 * @property string $color
 * @property string $url
 * @property int $status 0-pending,1-published
 * @property int $on_homepage_main_slider
 * @property int $on_homepage_second_slider
 * @property int $is_online
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 * @property string $type
 *
 * @property Product $parent
 * @property Service[] $services
 */
class SubProduct extends ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'sub_product';
    }


    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['title', 'brief'], 'required'],
            [['created_by', 'updated_by', 'status', 'revision', 'on_homepage_main_slider', 'on_homepage_second_slider', 'is_online'], 'integer'],
            [['slug', 'image', 'icon_1', 'icon_2', 'icon_3', 'view', 'layout', 'type', 'image_header', 'url', 'sub_title', 'brief'], 'string', 'max' => 255],
            [['color'], 'string', 'max' => 7],
            ['slug', 'unique'],
            [['created_at', 'updated_at', 'start_date', 'end_date'], 'safe'],
            [['title', 'content', 'view', 'layout'], 'string'],
            ['published_at', 'date', 'timestampAttribute' => 'published_at', 'format' => 'yyyy-MM-dd'],
            ['published_at', 'default', 'value' => time()],
            [['parent_id'], 'exist', 'skipOnError' => true, 'targetClass' => Product::className(), 'targetAttribute' => ['parent_id' => 'id']],



        ];
    }


    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
                'ensureUnique' => true,
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%sub_product_lang}}",
                'attributes' => [
                    'title', 'sub_title', 'content', 'brief'
                ]
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'parent_id' => Yii::t('app', 'Product'),
            'parent' => Yii::t('app', 'Product'),
            'slug' => Yii::t('app', 'Slug'),
            'image' => Yii::t('app', 'Image'),
            'image_header' => Yii::t('app', 'Image Header'),
            'icon_1' => Yii::t('app', 'Icon 1'),
            'icon_2' => Yii::t('app', 'Icon 2'),
            'icon_3' => Yii::t('app', 'Icon 3'),
            'color' => Yii::t('app', 'Color'),
            'url' => Yii::t('app', 'Url'),
            'status' => Yii::t('app', 'Status'),
            'on_homepage_main_slider' => Yii::t('app', 'On Homepage Main Slider'),
            'on_homepage_second_slider' => Yii::t('app', 'On Homepage Second Slider'),
            'is_online' => Yii::t('app', 'Is Online'),
            'published_at' => Yii::t('app', 'Published At'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
            'created_by' => Yii::t('app', 'Created By'),
            'updated_by' => Yii::t('app', 'Updated By'),
            'revision' => Yii::t('app', 'Revision'),
            'view' => Yii::t('app', 'View'),
            'layout' => Yii::t('app', 'Layout'),
            'type' => Yii::t('app', 'Type'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParent()
    {
        return $this->hasOne(Product::className(), ['id' => 'parent_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSubProductLangs()
    {
        return $this->hasMany(SubProductLang::className(), ['parent_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getServices()
    {
        return $this->hasMany(Service::className(), ['parent_id' => 'id']);
    }
    /**
     * @return \yii\db\ActiveQuery
     */
    public function getServicesWithVoucher()
    {
        return $this->hasMany(Service::className(), ['parent_id' => 'id'])->andWhere(['is_voucher' => 1]);
    }
    /**
     * {@inheritdoc}
     * @return SubProductQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new SubProductQuery(get_called_class());
    }




    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getStatusList()[$this->status];
    }


    public function getRevision()
    {
        return ($this->isNewRecord) ? 1 : $this->revision;
    }

    public function updateRevision()
    {
        $this->updateCounters(['revision' => 1]);
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            Utility::STATUS_PENDING => Yii::t('yee', 'Pending'),
            Utility::STATUS_PUBLISHED => Yii::t('yee', 'Published'),
        ];
    }


    /**
     * getStatusOptionsList
     * @return array
     */
    public static function getStatusOptionsList()
    {
        return [
            [Utility::STATUS_PENDING, Yii::t('yee', 'Pending'), 'default'],
            [Utility::STATUS_PUBLISHED, Yii::t('yee', 'Published'), 'primary']
        ];
    }

    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }

    /**
     * getStatusOptionsList
     * @return string
     */
    public function __toString()
    {
        return $this->title;
    }

    public function save($runValidation = true, $attributeNames = null)
    {
        \Yii::$app->cache->flush();
        return parent::save($runValidation, $attributeNames);
    }
}
