<?php

namespace backend\modules\product\models\search;

use backend\modules\product\models\Service;
use backend\modules\product\models\SubProduct;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\product\models\Product;

/**
 * ProductSearch represents the model behind the search form about `backend\modules\product\models\Product`.
 */
class ServiceSearch extends Service
{
    public $published_at_operand;


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'parent_id', 'status', 'published_at', 'created_at', 'updated_at', 'created_by', 'updated_by', 'revision'], 'integer'],
            [['published_at_operand', 'slug', 'title', 'image', 'icon_1','icon_2','icon_3', 'on_homepage_main_slider', 'on_homepage_second_slider', 'view', 'layout'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Service::find();

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
            'sort' => [
                'defaultOrder' => [
                    'id' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        $query->andFilterWhere([
            'id' => $this->id,
            'parent_id' => $this->parent_id,
            'status' => $this->status,
            'published_at' => $this->published_at,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'revision' => $this->revision,
        ]);
        $query->andFilterWhere([($this->published_at_operand) ? $this->published_at_operand : '=', 'published_at', ($this->published_at) ? strtotime($this->published_at) : null]);

        $query->andFilterWhere(['like', 'slug', $this->slug])
            ->andFilterWhere(['like', 'image', $this->image])
//            ->andFilterWhere(['like', 'icon', $this->icon])
            ->andFilterWhere(['like', 'on_homepage_main_slider', $this->on_homepage_main_slider])
            ->andFilterWhere(['like', 'on_homepage_second_slider', $this->on_homepage_second_slider])
            ->andFilterWhere(['like', 'view', $this->view])
            ->andFilterWhere(['like', 'layout', $this->layout]);

        return $dataProvider;
    }
}
