<?php

use backend\modules\product\models\Product;
use kartik\widgets\Select2;
use yeesoft\helpers\Html;
use yeesoft\media\widgets\TinyMce;
use yeesoft\models\User;
use yeesoft\widgets\ActiveForm;
use yeesoft\widgets\LanguagePills;
use yii\helpers\ArrayHelper;
use yii\jui\DatePicker;
use backend\modules\product\models\SubProduct;

/* @var $this yii\web\View */
/* @var $model \backend\modules\product\models\SubProduct */
/* @var $form yeesoft\widgets\ActiveForm */
?>

    <div class="page-form">

        <?php
        $form = ActiveForm::begin([
            'id' => 'product-form',
            'validateOnBlur' => false,
            'options' => [
                'autocomplete' => 'off'
            ]
        ])
        ?>
        <?= $form->errorSummary($model, ['class' => 'alert alert-danger']); ?>


        <div class="row">
            <div class="col-md-9">

                <div class="panel panel-default">
                    <div class="panel-body">

                        <?php if ($model->isMultilingual()): ?>
                            <?= LanguagePills::widget() ?>
                        <?php endif; ?>

                        <?= $form->field($model, 'title')->textInput(['maxlength' => true]) ?>




                    </div>
                </div>
            </div>

            <div class="col-md-3">

                <div class="panel panel-default">
                    <div class="panel-body">
                        <div class="record-info">
                            <?php if (!$model->isNewRecord): ?>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['created_at'] ?> :
                                    </label>
                                    <span><?= $model->createdDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_at'] ?> :
                                    </label>
                                    <span><?= $model->updatedDatetime ?></span>
                                </div>

                                <div class="form-group clearfix">
                                    <label class="control-label" style="float: left; padding-right: 5px;">
                                        <?= $model->attributeLabels()['updated_by'] ?> :
                                    </label>
                                    <span><?= $model->updatedBy->username ?></span>
                                </div>

                            <?php endif; ?>

                            <div class="form-group">
                                <?php if ($model->isNewRecord): ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                    <?= Html::a(Yii::t('yee', 'Cancel'), ['/product/sub-product-schedule/index'], ['class' => 'btn btn-default',]) ?>
                                <?php else: ?>
                                    <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                    <?=
                                    Html::a(Yii::t('yee', 'Delete'), ['/product/sub-product-schedule/delete', 'id' => $model->id], [
                                        'class' => 'btn btn-default',
                                        'data' => [
                                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                            'method' => 'post',
                                        ],
                                    ])
                                    ?>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="panel panel-default">
                    <div class="panel-body">

                        <div class="record-info">
                            <?=  $form->field($model, 'parent_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                'data' => ArrayHelper::map(SubProduct::find()->where(['status' => 1])->all(), 'id', 'title')
                            ]) ?>


                            <?=
                             $form->field($model, 'published_at')
                                ->widget(\kartik\widgets\DateTimePicker::className(), [
                                    'pluginOptions' => [
                                        'autoclose' => true,
                                        'weekStart' => 6,
                                        'minView' => 1,
                                        'hoursDisabled' => '0,1,2,3,4,5,6,7,8,16,17,18,19,20,21,22,23'
                                    ],
                                ]);?>

                            <?= $form->field($model, 'status')->dropDownList(SubProduct::getStatusList()) ?>

                            <?php if (!$model->isNewRecord): ?>
                                <?= $form->field($model, 'created_by')->dropDownList(User::getUsersList()) ?>
                            <?php endif; ?>

                            <?php $form->field($model, 'view')->dropDownList($this->context->module->viewList) ?>

                            <?php $form->field($model, 'layout')->dropDownList($this->context->module->layoutList) ?>

                        </div>
                    </div>
                </div>



            </div>
        </div>

        <?php ActiveForm::end(); ?>

    </div>


<?php


$js = <<<JS
    var image = $("#product-image").val();
    if(image.length == 0){
        $('.post-image').hide();
    } else {
        $('.post-image').html('<img src="' + image + '" />');
    }
     var image = $("#product-image_header").val();
    if(image.length == 0){
        $('.post-image_header').hide();
    } else {
        $('.post-image_header').html('<img src="' + image + '" />');
    }
    

JS;

$this->registerJs($js, yii\web\View::POS_END);
?>