<?php

use kartik\grid\GridView;
use yeesoft\grid\GridPageSize;
use yeesoft\grid\GridQuickLinks;
use yeesoft\helpers\Html;
use yeesoft\models\User;
use yii\helpers\Url;
use yii\widgets\Pjax;
use backend\modules\product\models\SubProduct;
use backend\modules\product\models\SubProductSchedule;

/* @var $this yii\web\View */
/* @var $searchModel \backend\modules\product\models\SubProduct */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('site', 'Sub Products Schedule');
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="page-index">

    <div class="row">
        <div class="col-sm-12">
            <h3 class="lte-hide-title page-title"><?= Html::encode($this->title) ?></h3>
            <?= Html::a(Yii::t('yee', 'Add New'), ['/product/sub-product-schedule/create'], ['class' => 'btn btn-sm btn-primary']) ?>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-body">

            <div class="row">
                <div class="col-sm-6">
                    <?= GridQuickLinks::widget([
                        'model' => SubProduct::className(),
                        'searchModel' => $searchModel,
                        'labels' => [
                            'all' => Yii::t('yee', 'All'),
                            'active' => Yii::t('yee', 'Published'),
                            'inactive' => Yii::t('yee', 'Pending'),
                        ],
                    ]) ?>
                </div>

                <div class="col-sm-6 text-right">
                    <?= GridPageSize::widget(['pjaxId' => 'page-grid-pjax']) ?>
                </div>
            </div>

            <?php Pjax::begin(['id' => 'page-grid-pjax', 'options' => ['autocomplete' => 'off']]) ?>

            <?php try {
                echo
                GridView::widget([
                    'id' => 'page-grid',
                    'dataProvider' => $dataProvider,
                    'filterModel' => $searchModel,
//                    'bulkActionOptions' => [
//                        'gridId' => 'page-grid',
//                        'actions' => [
//                            Url::to(['bulk-activate']) => Yii::t('yee', 'Publish'),
//                            Url::to(['bulk-deactivate']) => Yii::t('yee', 'Unpublish'),
//                            Url::to(['bulk-delete']) => Yii::t('yii', 'Delete'),
//                        ]
//                    ],
                    'columns' => [
                        ['class' => 'yeesoft\grid\CheckboxColumn', 'options' => ['style' => 'width:10px']],
                        [
                            'class' => 'yeesoft\grid\columns\TitleActionColumn',
                            'controller' => '/product/sub-product-schedule',
                            'title' => function (SubProductSchedule $model) {
                                return Html::a($model->title, ['/product/sub-product-schedule/view', 'id' => $model->id], ['data-pjax' => 0]);
                            },
//                            'buttonsTemplate' => '{view} {update} {delete}',

                        ],
                        //
                        [
                            'attribute' => 'published_at',
                            'visible' => true,
                            //'format' => ['date', 'php:Y-m-d'],
                            'filterType' => \kartik\grid\GridView::FILTER_DATE_RANGE,
                            'filterWidgetOptions' => ([
//                                'containerTemplate' => $containerTemplate,
                                'hideInput' => false,
                                'presetDropdown' => false,
                                'convertFormat' => true,
                                'options' => [
                                    'autocomplete' => 'off',
                                ],
                                'pluginOptions' => [
                                    'locale' => ['format' => 'Y-m-d'],
                                    'opens' => 'left',
//                                    'weekStart' => 6,
//                                    'weekStart' => '4',
//                                    'firstDay' => '4',
                                    //                                    //'separator'=>' to '
//                                    'allowClear' => true,
//                                    //To Custom Ranges, should set presetDropdown=false
                                    'ranges' =>
                                        [
                                            Yii::t('app', "Today") => ["moment().startOf('day')", "moment()"],
                                            Yii::t('app', "Yesterday") => ["moment().startOf('day').subtract(1,'days')", "moment().endOf('day').subtract(1,'days')"],
                                            Yii::t('app', "Last {n} Days", ['n' => 7]) => ["moment().startOf('day').subtract(6, 'days')", "moment()"],
                                            Yii::t('app', "Last {n} Days", ['n' => 30]) => ["moment().startOf('day').subtract(29, 'days')", "moment()"],
                                            Yii::t('app', "This Week") => ["moment().startOf('week')", "moment().endOf('week')"],
                                            Yii::t('app', "Next Week") => ["moment().add(1, 'week').startOf('week')", "moment().add(1, 'week').endOf('week')"],
                                            Yii::t('app', "This Month") => ["moment().startOf('month')", "moment().endOf('month')"],
                                            Yii::t('app', "Next Month") => ["moment().add(1, 'month').startOf('month')", "moment().add(1, 'month').endOf('month')"],
                                        ],
//                                    'pluginEvents' => [
//                                        //'cancel.daterangepicker'=>'function(ev, picker) { $("#opportunitieslistview-created").val("") } '
//                                    ]
                                ]]),
                            'value' => function ($data) {
                                return $data->published_at;
                            }
                        ],
                        [
                            'attribute' => 'parent_id',
                            'filter' => \yii\helpers\ArrayHelper::map(\backend\modules\product\models\Product::find()->all(), 'id', 'title'),
                            'value' => function (SubProductSchedule $model) {
                                return $model->parent;
                            },
                        ],
                        [
                            'class' => 'yeesoft\grid\columns\StatusColumn',
                            'attribute' => 'status',
                            'optionsArray' => SubProductSchedule::getStatusOptionsList(),
                            'options' => ['style' => 'width:60px'],
                        ],
//                        [
//                            'class' => 'yeesoft\grid\columns\DateFilterColumn',
//                            'attribute' => 'published_at',
//                            'value' => function (SubProduct $model) {
//                                return '<span style="font-size:85%;" class="label label-'
//                                    . ((time() >= $model->published_at) ? 'primary' : 'default') . '">'
//                                    . $model->publishedDate . '</span>';
//                            },
//                            'format' => 'raw',
//                            'options' => ['style' => 'width:150px'],
//                        ],
                    ],
                ]);
            } catch (Exception $e) {
                var_dump($e->getMessage());
            }
            ?>

            <?php Pjax::end() ?>
        </div>
    </div>
</div>


