<?php

namespace backend\modules\quotes_criteria\models;

use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\SluggableBehavior;

/**
 * This is the model class for table "car_brand".
 *
 * @property int $id
 * @property string $code
 * @property string $title
 * @property int $max_car_age
 */
class CarBrand extends ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'car_brand';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'slugAttribute' => 'code',
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'brand_id',
                'tableName' => "{{%car_brand_lang}}",
                'attributes' => [
                    'title',
                ]
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['max_car_age', 'title'], 'required'],
            [['max_car_age'], 'integer'],
            [['code', 'title'], 'string', 'max' => 55],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'code' => Yii::t('site', 'Code'),
            'title' => Yii::t('site', 'Title'),
            'max_car_age' => Yii::t('site', 'Max Car Age'),
        ];
    }


    /**
     * {@inheritdoc}
     * @return CarBrandQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new CarBrandQuery(get_called_class());
    }

}
