<?php

namespace backend\modules\quotes_criteria\models;

use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\SluggableBehavior;

/**
 * This is the model class for table "car_model".
 *
 * @property int $id
 * @property int $car_brand_id
 * @property string $code
 * @property string $title
 *
 * @property CarBrand $carBrand
 */
class CarModel extends ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'car_model';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'slugAttribute' => 'code',
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'model_id',
                'tableName' => "{{%car_model_lang}}",
                'attributes' => [
                    'title',
                ]
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['car_brand_id'], 'integer'],
            [['car_brand_id', 'title'], 'required'],
            [['code', 'title'], 'string', 'max' => 125],
            [['car_brand_id'], 'exist', 'skipOnError' => true, 'targetClass' => CarBrand::className(), 'targetAttribute' => ['car_brand_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'car_brand_id' => Yii::t('site', 'Car Brand'),
            'code' => Yii::t('site', 'Code'),
            'title' => Yii::t('site', 'Title'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCarBrand()
    {
        return $this->hasOne(CarBrand::className(), ['id' => 'car_brand_id']);
    }

    /**
     * {@inheritdoc}
     * @return CarBrandQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new CarBrandQuery(get_called_class());
    }

}
