<?php

namespace backend\modules\quotes_request\models;

use backend\modules\quotes_request\forms\IndividualInsuranceForm;
use bedezign\yii2\audit\AuditTrailBehavior;
use common\helpers\Utility;
use DateTime;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\web\UploadedFile;

/**
 * This is the model class for table "individual_medical_insurance_family_list".
 *
 * @property int $id
 * @property int $parent_number
 * @property string $first_name_ar
 * @property string $second_name_ar
 * @property string $third_name_ar
 * @property string $family_name_ar
 * @property string $first_name_en
 * @property string $second_name_en
 * @property string $third_name_en
 * @property string $family_name_en
 * @property string $mobile_number
 * @property string $gender
 * @property string $date_of_birth
 * @property string $relationship
 * @property string $length
 * @property string $weight
 * @property string $blood_type
 * @property string $career
 * @property string $nationality
 * @property string $national_number
 * @property string $photo_file
 *
 * @property IndividualMedicalInsurance $parentNumber
 */
class IndividualMedicalInsuranceFamilyList extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'individual_medical_insurance_family_list';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['parent_number'], 'integer'],
            [['date_of_birth'], 'safe'],
            [['first_name_ar', 'second_name_ar', 'third_name_ar', 'family_name_ar', 'first_name_en', 'second_name_en', 'third_name_en', 'family_name_en', 'relationship', 'length', 'weight', 'blood_type', 'career', 'nationality', 'photo_file'], 'string', 'max' => 255],
            [['mobile_number', 'national_number'], 'string', 'max' => 50],
            [['gender'], 'string', 'max' => 10],
            [['parent_number'], 'exist', 'skipOnError' => true, 'targetClass' => IndividualMedicalInsurance::className(), 'targetAttribute' => ['parent_number' => 'id']],
            [['photo_file', 'national_number', 'date_of_birth','gender','first_name_ar', 'second_name_ar', 'third_name_ar', 'family_name_ar', 'first_name_en', 'second_name_en', 'third_name_en', 'family_name_en', 'relationship', 'length', 'weight', 'blood_type', 'career', 'nationality'], 'required'],
            [['photo_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'jpg, jpeg, png, bmp, pdf'],

        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
//            'Timestamp' => [
//                'class' => TimestampBehavior::className(),
                //'createdAtAttribute' => 'created',
                //'updatedAtAttribute' => 'updated',
//            ],
//           BlameableBehavior::className(),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'parent_number' => Yii::t('site', 'Parent Number'),
            'first_name_ar' => Yii::t('site', 'Arabic First Name'),
            'second_name_ar' => Yii::t('site', 'Arabic Second Name'),
            'third_name_ar' => Yii::t('site', 'Arabic Third Name'),
            'family_name_ar' => Yii::t('site', 'Arabic Family Name'),
            'first_name_en' => Yii::t('site', 'English First Name'),
            'second_name_en' => Yii::t('site', 'English Second Name'),
            'third_name_en' => Yii::t('site', 'English Third Name'),
            'family_name_en' => Yii::t('site', 'English Family Name'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'gender' => Yii::t('site', 'Gender'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'relationship' => Yii::t('site', 'Relationship'),
            'length' => Yii::t('site', 'Length'),
            'weight' => Yii::t('site', 'Weight'),
            'blood_type' => Yii::t('site', 'Blood Type'),
            'career' => Yii::t('site', 'Career'),
            'nationality' => Yii::t('site', 'Nationality'),
            'national_number' => Yii::t('site', 'National Number'),
            'photo_file' => Yii::t('site', 'Photo File'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParentNumber()
    {
        return $this->hasOne(IndividualMedicalInsurance::className(), ['id' => 'parent_number']);
    }

    /**
     * {@inheritdoc}
     * @return IndividualMedicalInsuranceFamilyListQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new IndividualMedicalInsuranceFamilyListQuery(get_called_class());
    }

    public function calculateQuote()
    {
        $price = $additional_price = 0;
        // My Birthday
        $date_1 = new DateTime($this->date_of_birth);
        // Todays date
        $date_2 = new DateTime(date('Y-m-d'));
        $difference = $date_2->diff($date_1);

//inpatient_male_vip_20
        $plan = strtolower($this->parentNumber->programe_type) . '_' . strtolower($this->gender) . '_' . strtolower($this->parentNumber->class_type) . '_' . IndividualInsuranceForm::getYearRang($difference->y);

        return (float)Yii::$app->settings->get('individual_insurance.' . $plan);

    }

    public function uploadFiles($file){
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/quote', // Path for uploaded files in web directory
        ];
        try {

            $media = Utility::saveUploadedFile($file, $routes);
            $this->photo_file = $media->url;

        } catch (\Exception $e) {

        }
    }
}
