<?php

namespace backend\modules\quotes_request\models;

use backend\modules\quotes_criteria\models\PersonalAccidentsSettings;
use bedezign\yii2\audit\AuditTrailBehavior;
use Yii;
use yii\behaviors\TimestampBehavior;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "personal_accidents_insurance".
 *
 * @property int $id
 * @property string $reference_number
 * @property string $first_name
 * @property string $second_name
 * @property string $third_name
 * @property string $family_name
 * @property string $email
 * @property string $mobile_number
 * @property string $date_of_birth
 * @property string $duration
 * @property string $amount
 * @property string $work
 * @property string $start_date
 * @property string $file
 * @property string $beneficiary
 * @property string $address
 * @property string $pobox
 * @property string $postal_code
 * @property string $initial_price
 * @property string $discount
 * @property string $final_price
 * @property string $request_status
 * @property string $payment_method
 * @property int $medical_expenses
 * @property int $created
 * @property int $updated
 */
class PersonalAccidentsInsurance extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'personal_accidents_insurance';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date_of_birth', 'start_date'], 'safe'],
            [['amount', 'initial_price', 'discount', 'final_price', 'medical_expenses'], 'number'],
            [['work', 'address'], 'string'],
            [['created', 'updated'], 'integer'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'duration', 'file', 'beneficiary', 'pobox', 'postal_code', 'request_status', 'payment_method'], 'string', 'max' => 255],
            [['mobile_number', 'gender'], 'string', 'max' => 50],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created',
                'updatedAtAttribute' => 'updated',
            ],
//            BlameableBehavior::className(),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Number'),
            'first_name' => Yii::t('site', 'First Name'),
            'second_name' => Yii::t('site', 'Second Name'),
            'third_name' => Yii::t('site', 'Third Name'),
            'family_name' => Yii::t('site', 'Family Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'duration' => Yii::t('site', 'Duration'),
            'amount' => Yii::t('site', 'Amount'),
            'work' => Yii::t('site', 'Work'),
            'start_date' => Yii::t('site', 'Start Date'),
            'file' => Yii::t('site', 'File'),
            'beneficiary' => Yii::t('site', 'Beneficiary'),
            'address' => Yii::t('site', 'Address'),
            'pobox' => Yii::t('site', 'Pobox'),
            'postal_code' => Yii::t('site', 'Postal Code'),
            'initial_price' => Yii::t('site', 'Initial Price'),
            'discount' => Yii::t('site', 'Discount'),
            'final_price' => Yii::t('site', 'Final Price'),
            'request_status' => Yii::t('site', 'Request Status'),
            'payment_method' => Yii::t('site', 'Payment Method'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
        ];
    }

    /**
     * {@inheritdoc}
     * @return PersonalAccidentsInsuranceQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new PersonalAccidentsInsuranceQuery(get_called_class());
    }

    public static function getAmounts()
    {
        return array_combine(array_keys(PersonalAccidentsSettings::getList()), array_keys(PersonalAccidentsSettings::getList()));

    }

}
