<?php

namespace backend\modules\quotes_request\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use common\helpers\Utility;
use Yii;
use yii\behaviors\TimestampBehavior;
use yii\web\UploadedFile;

/**
 * This is the model class for table "travel_insurance".
 *
 * @property int $id
 * @property string $reference_number
 * @property string $first_name
 * @property string $second_name
 * @property string $third_name
 * @property string $family_name
 * @property string $email
 * @property string $mobile_number
 * @property string $date_of_birth
 * @property string $destination
 * @property string $gender
 * @property string $Duration
 * @property string $plan_type
 * @property string $passport_number
 * @property string $passport_expiry_date
 * @property string $passport_file
 * @property string $travel_date
 * @property string $address
 * @property string $nationality
 * @property string $initial_price
 * @property string $discount
 * @property string $final_price
 * @property string $request_status
 * @property string $payment_method
 * @property int $created
 * @property int $updated
 */
class TravelInsurance extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'travel_insurance';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date_of_birth', 'passport_expiry_date', 'travel_date'], 'safe'],
            [['address'], 'string'],
            [['initial_price', 'discount', 'final_price'], 'number'],
            [['created', 'updated'], 'integer'],
            [['reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'destination', 'gender', 'Duration', 'plan_type', 'passport_file', 'nationality', 'request_status', 'payment_method'], 'string', 'max' => 255],
            [['passport_file', 'address', 'date_of_birth', 'passport_expiry_date', 'travel_date', 'mobile_number', 'passport_number', 'reference_number', 'first_name', 'second_name', 'third_name', 'family_name', 'email', 'destination', 'gender', 'plan_type', 'nationality'], 'required'],
            [['mobile_number', 'passport_number'], 'string', 'max' => 50],
            ['travel_date', 'compare', 'compareAttribute' => 'passport_expiry_date', 'operator' => '<', 'type' => 'date'],
            ['date_of_birth', 'compare', 'compareValue' => date('Y-m-d'), 'operator' => '<=', 'type' => 'date'],
            [['passport_file'], 'file', 'maxSize' => 1024 * 1024 * 50, 'extensions' => 'jpg, jpeg, png, bmp, pdf'],


        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created',
                'updatedAtAttribute' => 'updated',
            ],
//            BlameableBehavior::className(),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Number'),
            'first_name' => Yii::t('site', 'First Name'),
            'second_name' => Yii::t('site', 'Second Name'),
            'third_name' => Yii::t('site', 'Third Name'),
            'family_name' => Yii::t('site', 'Family Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'date_of_birth' => Yii::t('site', 'Date Of Birth'),
            'destination' => Yii::t('site', 'Destination'),
            'gender' => Yii::t('site', 'Gender'),
            'Duration' => Yii::t('site', 'Duration'),
            'plan_type' => Yii::t('site', 'Plan Type'),
            'passport_number' => Yii::t('site', 'Passport Number'),
            'passport_expiry_date' => Yii::t('site', 'Passport Expiry Date'),
            'passport_file' => Yii::t('site', 'Passport File'),
            'travel_date' => Yii::t('site', 'Travel Date'),
            'address' => Yii::t('site', 'Address'),
            'nationality' => Yii::t('site', 'Nationality'),
            'initial_price' => Yii::t('site', 'Initial Price'),
            'discount' => Yii::t('site', 'Discount'),
            'final_price' => Yii::t('site', 'Final Price'),
            'request_status' => Yii::t('site', 'Request Status'),
            'payment_method' => Yii::t('site', 'Payment Method'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
        ];
    }

    /**
     * {@inheritdoc}
     * @return TravelInsuranceQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new TravelInsuranceQuery(get_called_class());
    }


    public function setDefaults()
    {
        $this->reference_number = Utility::create_guid();
    }

    public static function getTravelPlans(){
//Yii::$app->settings->get('travel.worldwide_7_days')
        return [
            'Worldwide' => [
                'travel.worldwide_7_days' => Yii::t('site', '1 - 7 Days'),
                'travel.worldwide_10_days' => Yii::t('site', '1 - 10 Days'),
                'travel.worldwide_15_days' => Yii::t('site', '1 - 15 Days'),
                'travel.worldwide_21_days' => Yii::t('site', '1 - 21 Days'),
                'travel.worldwide_31_days' => Yii::t('site', '1 - 31 Days'),
                'travel.worldwide_62_days' => Yii::t('site', '1 - 62 Days'),
                'travel.worldwide_92_days' => Yii::t('site', '1 - 92 Days'),
                'travel.worldwide_180_days' => Yii::t('site', '1 - 180 Days'),
                'travel.worldwide_1_year' => Yii::t('site', '1 Year'),
                'travel.worldwide_2_year' => Yii::t('site', '2 Year'),
            ],
            'Schengen' => [
                'travel.schengen_7_days' => Yii::t('site', '1 - 7 Days'),
                'travel.schengen_10_days' => Yii::t('site', '1 - 10 Days'),
                'travel.schengen_15_days' => Yii::t('site', '1 - 15 Days'),
                'travel.schengen_21_days' => Yii::t('site', '1 - 21 Days'),
                'travel.schengen_31_days' => Yii::t('site', '1 - 31 Days'),
                'travel.schengen_62_days' => Yii::t('site', '1 - 62 Days'),
                'travel.schengen_92_days' => Yii::t('site', '1 - 92 Days'),
                'travel.schengen_180_days' => Yii::t('site', '1 - 180 Days'),
                'travel.schengen_1_year' => Yii::t('site', '1 Year'),
                'travel.schengen_2_year' => Yii::t('site', '2 Year'),
            ],
            'Middle East or SCHENGEN Plus Plans' => [
                'travel.middle_east_7_days' => Yii::t('site', '1 - 7 Days'),
                'travel.middle_east_10_days' => Yii::t('site', '1 - 10 Days'),
                'travel.middle_east_15_days' => Yii::t('site', '1 - 15 Days'),
                'travel.middle_east_21_days' => Yii::t('site', '1 - 21 Days'),
                'travel.middle_east_31_days' => Yii::t('site', '1 - 31 Days'),
                'travel.middle_east_62_days' => Yii::t('site', '1 - 62 Days'),
                'travel.middle_east_92_days' => Yii::t('site', '1 - 92 Days'),
                'travel.middle_east_180_days' => Yii::t('site', '1 - 180 Days'),
                'travel.middle_east_1_year' => Yii::t('site', '1 Year'),
                'travel.middle_east_2_year' => Yii::t('site', '2 Year'),
            ],
            'Hajj & Umra Plan' => [
                'travel.hajj_5_days' => Yii::t('site', 'Up to 5 days'),
                'travel.hajj_7_days' => Yii::t('site', '6-7 days'),
                'travel.hajj_10_days' => Yii::t('site', '8-10 days'),
                'travel.hajj_14_days' => Yii::t('site', '11-14 days'),
                'travel.hajj_21_days' => Yii::t('site', '15-21 days'),
                'travel.hajj_31_days' => Yii::t('site', '22-31 days'),
                ],
        ];
    }


    public function calculateQuote()
    {
        $price = 0;

        $price = (float) Yii::$app->settings->get($this->plan_type);

        $days = Utility::dateDifference($this->date_of_birth, date('Y-m-d'), '%d');

        if($days <= 10){
            $price = ($price - ($price * Yii::$app->settings->get('travel.loading_10')));
        }elseif ($days <= 18){
            $price = ($price - ($price * Yii::$app->settings->get('travel.loading_18')));

        }else{
            $price = ($price + ($price * Yii::$app->settings->get('travel.loading_80')));
        }

        $this->initial_price = $this->final_price = $price;


        $discount = Yii::$app->settings->get('travel.discount');

        if ($discount) {
            $this->discount = ($this->initial_price * $discount / 100);
            $this->final_price = ($this->initial_price - $this->discount);
        }

    }


    /**
     * @param bool $insert
     * @return bool
     */
    public function beforeSave($insert)
    {
        if($insert) {
            $this->calculateQuote();
        }
        return parent::beforeSave($insert);
    }


    public function uploadFiles()
    {
        $routes = [
            'baseUrl' => '', // Base absolute path to web directory
            'basePath' => '@frontend/web', // Base web directory url
            'uploadPath' => 'uploads/quote', // Path for uploaded files in web directory
        ];
        try {
            $file1 = UploadedFile::getInstance(new self(), "passport_file");
            $media1 = Utility::saveUploadedFile($file1, $routes);
            //$this->familyBookFile = $media1->file;
            $this->passport_file = $media1->url;
        } catch (\Exception $e) {
        }

    }

}
