<?php

namespace backend\modules\testimonial\models;

use backend\modules\career\models\RecruitmentGuidanceTestimonial;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;

/**
 * This is the model class for table "news".
 *
 * @property int $id
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property string $url
 * @property string $image
 * @property string $category
 */
class Testimonial extends ActiveRecord
{

    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'testimonial';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%testimonial_lang}}",
                'attributes' => [
                    'title', 'second_title', 'brief', 'button_text', 'image',
                ]
            ],
        ];
    }


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['title', 'second_title', 'status'], 'required'],
            [['created_by', 'updated_by'], 'integer'],
            [['title', 'brief', 'button_text', 'second_title'], 'string', 'max' => 255],
            [['url', 'image'], 'string', 'max' => 255],
            [['created_at', 'updated_at'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'slug' => Yii::t('site', 'Slug'),
            'title' => Yii::t('site', 'Name'),
            'second_title' => Yii::t('site', 'Job Title'),
            'title_ar' => Yii::t('site', 'Name Arabic'),
            'second_title_ar' => Yii::t('site', 'Job Title Arabic'),
            'status' => Yii::t('site', 'Status'),
            'comment_status' => Yii::t('site', 'Comment Status'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
            'image' => Yii::t('site', 'Image'),
            'image_header' => Yii::t('site', 'BMS'),
            'start_date' => Yii::t('site', 'Start Campaign Date'),
            'end_date' => Yii::t('site', 'End Campaign Date'),

        ];
    }

    /**
     * {@inheritdoc}
     * @return TestimonialQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new TestimonialQuery(get_called_class());
    }



    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PENDING => Yii::t('site', 'Pending'),
            self::STATUS_PUBLISHED => Yii::t('site', 'Published'),
        ];
    }


    /**
     * getTypeList
     * @return array
     */
    public static function getCategoryList()
    {
        return [
            '' => Yii::t('site', ''),
            'HomePageTop' => Yii::t('site', 'HomePageTop'),
            'Newsletter' => Yii::t('site', 'Newsletter'),
            'diagnosisBanner' => Yii::t('site', 'diagnosisBanner'),
            'saveLivesBanner' => Yii::t('site', 'saveLivesBanner'),
//            'RecruitmentGuidance' => Yii::t('site', 'RecruitmentGuidance'),
        ];
    }


    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     *
     * @inheritdoc
     */
    public static function getOwnerField()
    {
        return 'created_by';
    }

    public function getThumbnail($options = ['class' => 'thumbnail pull-left', 'style' => 'width: 240px'])
    {

        if (!empty($this->image)) {
            return Html::img($this->image, $options);
        }

        return;
    }


}
