<?php

namespace backend\modules\vehicle\models;

use backend\modules\dropdown_list\models\DropdownList;
use Yii;

/**
 * This is the model class for table "vehicle_equipment".
 *
 * @property int $vehicle_id
 * @property int $equipment_id
 *
 * @property Vehicle $vehicle
 * @property DropdownList $equipment
 */
class VehicleEquipment extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle_equipment';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['vehicle_id', 'equipment_id'], 'required'],
            [['vehicle_id', 'equipment_id'], 'integer'],
            [['vehicle_id', 'equipment_id'], 'unique', 'targetAttribute' => ['vehicle_id', 'equipment_id']],
            [['vehicle_id'], 'exist', 'skipOnError' => true, 'targetClass' => Vehicle::className(), 'targetAttribute' => ['vehicle_id' => 'id']],
            [['equipment_id'], 'exist', 'skipOnError' => true, 'targetClass' => DropdownList::className(), 'targetAttribute' => ['equipment_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'vehicle_id' => Yii::t('site', 'Vehicle ID'),
            'equipment_id' => Yii::t('site', 'Equipment ID'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicle()
    {
        return $this->hasOne(Vehicle::className(), ['id' => 'vehicle_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEquipment()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'equipment_id']);
    }

    /**
     * {@inheritdoc}
     * @return VehicleEquipmentQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new VehicleEquipmentQuery(get_called_class());
    }
}
