<?php

namespace backend\modules\vehicle\models\search;

//use common\components\SolrSearch;
//use common\helpers\SolrDataProvider;
use common\components\SolrSearch;
use common\helpers\SolrDataProvider;
use Solarium\QueryType\Select\Query\Query;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\vehicle\models\Vehicle;

/**
 * VehicleSeach represents the model behind the search form about `backend\modules\vehicle\models\Vehicle`.
 */
class VehicleSearch extends Vehicle
{

    public $sort_by = 'created_at_i';
    public $price_from, $price_to;
    public $dist_km_from, $dist_km_to, $dist_mile_from, $dist_mile_to;
    public $vehicle_equipment;
    public $vehicle_remark;


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'owner_id', 'odometer_km', 'odometer_mile', 'cylinders_id', 'capacity', 'power', 'rim_size', 'drive_id', 'manufacturer_id', 'created_at', 'updated_at', 'created_by', 'updated_by','vehicle_type'], 'integer'],
            [[ 'color_id', 'interior_color_id', 'body_type_id', 'cylinders_id', 'capacity', 'engine_id', 'power', 'rim_size', 'transmission_id','manufacturer_model_id'],'safe'],
            [['owner_type_id', 'slug', 'status', 'model_year', 'front_left_status', 'front_right_status', 'back_left_status', 'back_right_status', 'video_file','vehicle_equipment','vehicle_remark'], 'safe'],
            [['price', 'price_from', 'price_to', 'dist_km_from', 'dist_km_to', 'dist_mile_from', 'dist_mile_to'], 'number'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    public function solrSearch($params)
    {

//        $lng = Yii::$app->language;
//        var_dump($params);die();

        $this->load($params);


//        var_dump($params, $this->transmission_id);die();
        /* @var $solr SolrSearch */

        $solr = Yii::$app->solr;
        $client = $solr->client;

// get a select query instance
        $query = $client->createSelect();

        //$query->createFilterQuery("status")->setQuery("status_i:1");


//        if ($this->wheelchair_accessible_avg_f) {
//            $query->createFilterQuery('wheelchair_accessible_avg_f')->setQuery("wheelchair_accessible_avg_f:[{$this->wheelchair_accessible_avg_f} TO 5]");
//        }
//        if ($this->spacious_interior_avg_f) {
//            $query->createFilterQuery('spacious_interior_avg_f')->setQuery("spacious_interior_avg_f:[{$this->spacious_interior_avg_f} TO 5]");
//        }
//        if ($this->lighting_brightness_avg_f) {
//            $query->createFilterQuery('lighting_brightness_avg_f')->setQuery("lighting_brightness_avg_f:[{$this->lighting_brightness_avg_f} TO 5]");
//        }
        if ($this->price_from || $this->price_to) {
            $this->price_from = ($this->price_from ? : '*');
            $this->price_to = ($this->price_to ? : '*');
            $query->createFilterQuery('price')->setQuery("price_i:[{$this->price_from} TO {$this->price_to}]");
        }
        if ($this->dist_km_from || $this->dist_km_to) {
            $this->dist_km_from = ($this->dist_km_from ? : '*');
            $this->dist_km_to = ($this->dist_km_to ? : '*');
            $query->createFilterQuery('dist_km')->setQuery("dist_km_i:[{$this->dist_km_from} TO {$this->dist_km_to}]");
        }
        if ($this->dist_mile_from || $this->dist_mile_to) {
            $this->dist_mile_from = ($this->dist_mile_from ? : '*');
            $this->dist_mile_to = ($this->dist_mile_to ? : '*');
            $query->createFilterQuery('dist_mile')->setQuery("dist_mile_i:[{$this->dist_mile_from} TO {$this->dist_mile_to}]");
        }
//
        if ($this->transmission_id) {
            $query->createFilterQuery("transmission_facet")->setQuery("transmission_facet_i:{$this->transmission_id}");
        }
        if ($this->manufacturer_model_id) {
            $query->createFilterQuery("manufacturer_model_facet")->setQuery("manufacturer_model_facet_i:{$this->manufacturer_model_id}");
        }
        if ($this->manufacturer_id) {
            $query->createFilterQuery("manufacturer_facet")->setQuery("manufacturer_facet_i:{$this->manufacturer_id}");
        }
        if ($this->body_type_id) {
            $query->createFilterQuery("body_type_facet")->setQuery("body_type_facet_i:{$this->body_type_id}");
        }
        if ($this->model_year) {
            $query->createFilterQuery('model_year')->setQuery("model_year_i:{$this->model_year}");
        }
        if ($this->owner_type_id) {
            $query->createFilterQuery("owner_type")->setQuery("owner_type_i:{$this->owner_type_id}");
        }
        if ($this->engine_id) {
            $query->createFilterQuery("engine_facet")->setQuery("engine_facet_i:{$this->engine_id}");
        }
        if ($this->color_id) {
            $query->createFilterQuery("color_facet")->setQuery("color_facet_i:{$this->color_id}");
        }
//        if ($this->sub_district_id) {
//            $query->createFilterQuery('district_id')->setQuery("subdistrict_i:{$this->sub_district_id}");
//        }
//
//        if ($this->subsector_id) {
//            $query->createFilterQuery('subsector_id')->setQuery("subsector_is:{$this->subsector_id}");
//        }
//        if (count($this->accessibility_is)) {
//            $values = implode(' OR ', $this->accessibility_is);
//            $query->createFilterQuery('accessibility_is')->setQuery("accessibility_is:({$values})");
//        }
//
//        if ($this->group_is) {
//            foreach ($this->group_is as $key => $group_i) {
//                $values = implode(' OR ', $group_i);
//                $query->createFilterQuery("group_{$key}_is")->setQuery("group_{$key}_is:({$values})");
//            }
////            var_dump($query->getFilterQueries());
//        }


//        if ($this->title) {
//            if(Yii::$app->language == 'ar') {
//                $str = implode(' AND ', explode(' ', trim($this->title)));
//                $query->setQuery("name_ar:({$str})");
//            }else{
//                $str = implode(' AND ', explode(' ', trim($this->title)));
//                $query->setQuery("name:({$str})");
//            }
//        }

        if($this->sort_by) {
            $query->addSort($this->sort_by, Query::SORT_DESC);
        }


// get the facetset component
        $facetSet = $query->getFacetSet();

        
        
// create a facet field instance and set options
        $facetSet->createFacetField('manufacturer_facet_i')->setField('manufacturer_facet_i');
        $facetSet->createFacetField('manufacturer_model_facet_i')->setField('manufacturer_model_facet_i');
        $facetSet->createFacetField('body_type_facet_i')->setField('body_type_facet_i');
        $facetSet->createFacetField('model_year_i')->setField('model_year_i');
        $facetSet->createFacetField('engine_facet_i')->setField('engine_facet_i');
        $facetSet->createFacetField('transmission_facet_i')->setField('transmission_facet_i');
        $facetSet->createFacetField('color_facet_i')->setField('color_facet_i');

        $facetSet->setMinCount(1);
        $facetSet->setSort('term:asc');


// this executes the query and returns the result
//        $resultset = $client->select($query);

// display the total number of documents found by solr
//        echo 'NumFound: ' . $resultset->getNumFound();


        $dataprovider = new SolrDataProvider([
            'solr' => $client,
            'query' => $query,
            'modelClass' => new Vehicle(),
            'pagination' => [
                'pageSize' => Yii::$app->settings->get('site.vehicle_page_size', Yii::$app->settings->get('site.default_page_size')),
            ],
        ]);
            // echo "<pre>";
            // \yii\helpers\VarDumper::dump($facetSet ,  $dept = 10,  $highlight = true);
            // die();
        return ($dataprovider);


//        return $this->search($params);
    }


    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Vehicle::find();
        $query->joinWith('vehicleRemarks')->distinct();
        $query->joinWith('vehicleEquipments')->distinct();


        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'sort' => [
                'defaultOrder' => [
                    'id' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }
         $query->filterWhere(['>=', 'price', $this->price_from]);
        $query->andFilterWhere(['<=', 'price', $this->price_to]);
        $query->filterWhere(['>=', 'odometer_mile', $this->dist_km_from]);
        $query->andFilterWhere(['<=', 'odometer_mile', $this->dist_km_to]);

        $query->andFilterWhere([
            'id' => $this->id,
            'vehicle_type'=>$this->vehicle_type,
            'owner_id' => $this->owner_id,
            'owner_type_id' => $this->owner_type_id,
            'price' => $this->price,
            'model_year' => $this->model_year,
            'odometer_km' => $this->odometer_km,
            'odometer_mile' => $this->odometer_mile,
            'cylinders_id' => $this->cylinders_id,
            'capacity' => $this->capacity,
            'power' => $this->power,
            'rim_size' => $this->rim_size,
            'drive_id' => $this->drive_id,
            'manufacturer_id' => $this->manufacturer_id,
            'measuring_the_distance_id'=>$this->measuring_the_distance_id,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'created_by' => $this->created_by,
            'updated_by' => $this->updated_by,
            'remark_id'=>$this->vehicle_remark,
        ]);

        $query->andFilterWhere(['like', 'slug', $this->slug])
            ->andFilterWhere(['like', 'status', $this->status])
            ->andFilterWhere(['color_id'=>$this->color_id ])
            ->andFilterWhere(['body_type_id'=>$this->body_type_id ])
            ->andFilterWhere(['equipment_id'=>$this->vehicle_equipment ])
            ->andFilterWhere(['interior_color_id'=>$this->interior_color_id ])
            ->andFilterWhere(['transmission_id'=>$this->transmission_id ])
            ->andFilterWhere(['engine_id'=>$this->engine_id ])
            ->andFilterWhere(['manufacturer_model_id'=>$this->manufacturer_model_id])
            ->andFilterWhere(['like', 'front_left_status', $this->front_left_status])
            ->andFilterWhere(['like', 'front_right_status', $this->front_right_status])
            ->andFilterWhere(['like', 'back_left_status', $this->back_left_status])
            ->andFilterWhere(['like', 'back_right_status', $this->back_right_status])
            ->andFilterWhere(['like', 'video_file', $this->video_file]);

        return $dataProvider;
    }
}
