<?php

use backend\modules\dropdown_list\models\DropdownList;
use backend\modules\vehicle\models\Vehicle;
use common\models\DropdownListLang;
use common\models\User;
use dosamigos\fileupload\FileUploadUI;
use kartik\select2\Select2;
use kartik\widgets\FileInput;
use yeesoft\helpers\Html;
use yeesoft\widgets\ActiveForm;
use yii\helpers\ArrayHelper;


/* @var $this yii\web\View */
/* @var $model backend\modules\vehicle\models\Vehicle */
/* @var $form yeesoft\widgets\ActiveForm */
Yii::$app->params['short_language'] = Yii::$app->language;
$dropDownList = new DropdownListLang();
?>

<div class="vehicle-form">
    <?php
    $form = ActiveForm::begin([
        'id' => 'vehicle-form',
        'validateOnBlur' => false,
    ])
    ?>
    <?= $form->errorSummary($model, ['class' => 'alert alert-danger']); ?>

    <div class="row">
        <div class="col-md-8">

            <div class="panel panel-default">
                <div class="panel-body">


                    <div class="clearfix"></div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?= $form->field($model, 'title')->textInput(['maxlength' => true]) ?>
                        </div>

                    </div>
                    <div class="row">


                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?=
                            // Controlling addon HTML options
                            $form->field($model, 'price', [
                                'addon' => [
                                    'prepend' => ['content' => 'JOD', 'options' => ['class' => 'alert-success']],
//                            'append' => ['content' => '.00', 'options'=>['style' => 'font-family: Monaco, Consolas, monospace;']],
                                ]
                            ]); ?>
                        </div>
                        <div class="col-sm-6">
                            <?= $form->field($model, "model_year")
                                ->widget(\kartik\widgets\DatePicker::classname(), [
                                    'pluginOptions' => [
                                        'autoclose' => true,
                                        'startView' => 'year',
                                        'minViewMode' => 'years',
                                        'format' => 'yyyy'
                                    ]
                                ]) ?>

                        </div>


                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?= $form->field($model, 'odometer_km')->textInput() ?>
                        </div>
                        <div class="col-sm-6">
                            <?= $form->field($model, 'odometer_mile')->textInput() ?>
                        </div>


                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?php echo $form->field($model, 'color_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleColors])->all(), 'id', 'title')
                            ]) ?>
                        </div>
                        <div class="col-sm-6">
                            <?php echo $form->field($model, 'interior_color_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleInteriorColor])->all(), 'id', 'title')
                            ]) ?>
                        </div>

                    </div>
                    <div class="row">


                        <div class="col-sm-3">
                            <?= $form->field($model, 'front_left_status')->textInput()
                                ->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>
                        </div>

                        <div class="col-sm-3">
                            <?= $form->field($model, 'front_right_status')->textInput()
                                ->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>
                        </div>

                        <div class="col-sm-3">
                            <?= $form->field($model, 'back_left_status')->textInput()
                                ->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>
                        </div>
                        <div class="col-sm-3">
                            <?= $form->field($model, 'back_right_status')->textInput()
                                ->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>

                        </div>

                    </div>
                    <div class="row">


                        <div class="col-sm-6">
                            <?php echo $form->field($model, 'body_type_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleBodyType])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('VehicleBodyType')
                            ]) ?>
                        </div>

                    </div>
                    <div class="row">
                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'cylinders_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                ///'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleCylinders])->all(), 'id', 'title')
                                'data' => $dropDownList->cylinder()
                            ]) ?>
                        </div>

                        <div class="col-sm-6">
                            <?= $form->field($model, 'capacity')->textInput() ?>

                        </div>

                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?php echo $form->field($model, 'engine_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleEngine])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('VehicleEngine')
                            ]) ?>
                        </div>

                        <div class="col-sm-6">
                            <?= $form->field($model, 'power')->textInput() ?>
                        </div>

                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?= $form->field($model, 'rim_size')->textInput() ?>
                        </div>

                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'transmission_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleTransmission])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('VehicleTransmission')
                            ]) ?>
                        </div>

                    </div>
                    <div class="row">
                        <div class="col-sm-6">
                            <?php echo $form->field($model, 'drive_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleDrive])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('VehicleDrive')
                            ]) ?>
                        </div>


                        <div class="col-sm-6">
                            <?= $form->field($model, 'video_file')->textInput(['maxlength' => true]) ?>
                        </div>

                    </div>
                    <div class="row">
                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'manufacturer_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleManufacturer])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('VehicleManufacturer')
                            ]) ?>
                        </div>
                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'manufacturer_model_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleModelManufacturer])->all(), 'id', 'title')
                            ]) ?>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'measuring_the_distance_id')->widget(Select2::className(), [
                                'options' => ['placeholder' => 'Select ...'],
                                'pluginOptions' => [
                                    'allowClear' => true
                                ],
                                //'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::MeasuringTheDistance])->all(), 'id', 'title')
                                'data' => $dropDownList->getDropdownList('MeasuringTheDistance')
                            ]) ?>
                        </div>

                        <div class="col-sm-6">

                            <?php echo $form->field($model, 'carseer_url')->textInput() ?>
                        </div>
                    </div>
                </div>

            </div>
        </div>

        <div class="col-md-4">

            <div class="panel panel-default">
                <div class="panel-body">
                    <div class="record-info">
                        <?php if (!$model->isNewRecord): ?>

                            <div class="form-group clearfix">
                                <label class="control-label"
                                       style="float: left; padding-right: 5px;"><?= $model->attributeLabels()['id'] ?>
                                    : </label>
                                <span><?= $model->id ?></span>
                            </div>
                            <div class="form-group clearfix">
                                <label class="control-label"
                                       style="float: left; padding-right: 5px;"><?= $model->attributeLabels()['slug'] ?>
                                    : </label>
                                <span><?= $model->slug ?></span>
                            </div>
                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['created_at'] ?> :
                                </label>
                                <span><?= $model->createdDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_at'] ?> :
                                </label>
                                <span><?= $model->updatedDatetime ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= $model->attributeLabels()['updated_by'] ?> :
                                </label>
                                <span><?= $model->updated_by?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= Yii::t('site', 'Owner User') ?> :
                                </label>
                                <span><?= (!empty($model->owner)) ? ((isset($model->owner->user) && !empty($model->owner->user)) ? $model->owner->user->name : '') : 'N/A' ?></span>
                            </div>

                            <div class="form-group clearfix">
                                <label class="control-label" style="float: left; padding-right: 5px;">
                                    <?= Yii::t('site', 'Contact #') ?> :
                                </label>
                                <span><?= (!empty($model->owner)) ? ((isset($model->owner->user) && !empty($model->owner->user)) ? $model->owner->user->phone : $model->owner->phone) : 'N/A' ?></span>
                            </div>

                        <?php endif; ?>
                        <?php echo $form->field($model, 'owner_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                                'data' => ArrayHelper::map(\backend\modules\vehicle\models\Owner::find()->where(['status' => \backend\modules\vehicle\models\Owner::STATUS_PUBLISHED])->all(), 'id', 'name')
                        ]) ?>
                        <?php echo $form->field($model, 'owner_type_id')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleOwnerType])->all(), 'id', 'title')
                        ]) ?>
                        <?php echo $form->field($model, 'vehicle_type')->widget(Select2::className(), [
                            'options' => ['placeholder' => 'Select ...'],
                            'pluginOptions' => [
                                'allowClear' => true
                            ],
                            'data' => [ 1=>'User Cars For Sale',2=>'New Car Deals',3=>'Certified Pre-Owned']
                        ]) ?>

                        <?= $form->field($model, 'status')->dropDownList(Vehicle::getStatusList()) ?>
                        <?= $form->field($model, 'is_featured')->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>
                        <?= $form->field($model, 'is_sold')->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>
                        <?= $form->field($model, 'car_type')->radioList(['1'=>'Car','2'=>360,'3'=>'Auction'], ['inline' => true]) ?>
                        <?= $form->field($model, 'is_private')->radioList(\common\helpers\Utility::getYesNoList(), ['inline' => true]) ?>

                        <?php if (!$model->isNewRecord): ?>
                            <?= $form->field($model, 'created_by')->dropDownList(User::getUsersList()) ?>
                        <?php endif; ?>

                        <div class="form-group">
                            <?php if ($model->isNewRecord): ?>
                                <?= Html::submitButton(Yii::t('yee', 'Create'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Cancel'), ['/vehicle/default/index'], ['class' => 'btn btn-default']) ?>
                            <?php else: ?>
                                <?= Html::submitButton(Yii::t('yee', 'Save'), ['class' => 'btn btn-primary']) ?>
                                <?= Html::a(Yii::t('yee', 'Delete'),
                                    ['/vehicle/default/delete', 'id' => $model->id], [
                                        'class' => 'btn btn-default',
                                        'data' => [
                                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                                            'method' => 'post',
                                        ],
                                    ]) ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="panel panel-default">
                <div class="panel-heading"><?php echo Yii::t('site', 'EQUIPMENT OVERVIEW') ?></div>

                <div class="panel-body">

                    <div class="record-info">
                        <?php try {
                            echo $form->field($model, 'equipmentValues')->label(false)->multiselect(
                                //ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleEquipments])->orderBy(['slug' => SORT_ASC])->all(), 'id', 'title'),
                                $dropDownList->getDropdownList('VehicleEquipments'),
                                [
                                    'height' => '225px',
                                    'container' => ['class' => 'bg-white']
                                ]
                            );
                        } catch (\yii\base\InvalidConfigException $e) {
                            var_dump($e->getMessage());
                        } ?>
                    </div>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-heading"><?php echo Yii::t('site', 'REMARKS') ?></div>

                <div class="panel-body">

                    <div class="record-info">
                        <?php try {
                            echo $form->field($model, 'remarkValues')->label(false)->multiselect(
                                //ArrayHelper::map(DropdownList::find()->where(['status' => 1, 'category' => DropdownList::VehicleRemarks])->all(), 'id', 'title'),
                                $dropDownList->getDropdownList('VehicleRemarks'),
                                [
                                    'height' => '225px',
                                    'container' => ['class' => 'bg-white']
                                ]
                            );
                        } catch (\yii\base\InvalidConfigException $e) {
                            var_dump($e->getMessage());
                        } ?>
                    </div>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-heading"><?php echo Yii::t('site', 'ATTACHMENTS') ?></div>

                <div class="panel-body">

                    <div class="record-info">
                        <?php try {
                            $fileModel = new yeesoft\media\models\Media();
                            echo
                            FileUploadUI::widget([
                                'model' => $fileModel,
                                'attribute' => 'file',
                                'url' => ['/media/manage/upload'],
                                'gallery' => true,
                                'options' => [
                                    'id' => 'media-file-360',
                                ],
                                'fieldOptions' => [
                                    'accept' => 'image/*,application/pdf'
                                ],
                                'clientOptions' => [
                                    'maxFileSize' => 10000000,
                                    'maxNumberOfFiles' => 1,
                                    'limitConcurrentUploads' => 1,
                                ],
                                // ...
                                'clientEvents' => [
                                    'fileuploaddone' => 'function(e, data) {
                                                    var result = data.result;
                                                    var file = result.files[0];
                                                    console.log(file.url);
                                                    $(\'<input>\').attr({
                                                        value: file.url,
                                                        type: \'hidden\',
                                                        name: \'Vehicle[attachmentsFiles][]\'
                                                    }).appendTo(\'form\');
                        
                                                          
                                                }',
                                    'fileuploadfail' => 'function(e, data) {
                        
                                                }',
                                ],
                            ]);
                        } catch (Exception $e) {
                        }
                        ?>
                    </div>

                </div>
                <?php if(!empty($model->inspectionReport)): ?>
                    <div class="panel-body">
                        <a  href="<?= $model->inspectionReport->getAttachmentFullPath() ?>" target="_blank" class="btn btn-default"><i class="fa fa-eye"></i> View uploaded document</a>
                    </div>
                <?php endif; ?>
            </div>




            <div class="panel panel-default">
                <div class="panel-heading"><?php echo Yii::t('site', '360 Images') ?></div>

                <div class="panel-body">

                    <div class="record-info">
                        <?= $form->field($model, 'image360')->label(false)->widget(yeesoft\media\widgets\FileInput::className(), [
                            'name' => 'image360',
                            'buttonTag' => 'button',
                            'buttonName' => Yii::t('site', 'Browse'),
                            'buttonOptions' => ['class' => 'btn btn-default btn-file-input'],
                            'options' => ['class' => 'form-control'],
                            'template' => '<div class="owner-image thumbnail"></div><div class="input-group">{input}<span class="input-group-btn">{button}</span></div>',
                            'thumb' => 'original',
                            'imageContainer' => '.owner-image',
                            'pasteData' => yeesoft\media\widgets\FileInput::DATA_URL,
                            'callbackBeforeInsert' => 'function(e, data) {
                                    $(".owner-image").show();
                                }',
                        ]) ?>
                    </div>
                </div>
            </div>

        </div>


    </div>

    <?php ActiveForm::end(); ?>

</div>



<script>

    var image = $("#vehicle-image360").val();
    if(image.length == 0){
        $('.owner-image').hide();
    } else {
        $('.owner-image').html('<img src="' + image + '" />');
    }

    $("#vehicle-manufacturer_id").on('change', function(e) {
        // Access to full data
        var parent_id =  $(this).val()
        $.ajax({
          url: '/vehicle/default/manufacturer-model?id='+ parent_id,
          type: 'get',
          success: function(data){

            $('#vehicle-manufacturer_model_id').html(null).trigger('change');
            $('#vehicle-manufacturer_model_id').val(null).trigger('change');
            $.each(data, function (i,e){
                var newOption = new Option(e.title, e.id, true, false);
                $("#vehicle-manufacturer_model_id").append(newOption).trigger('change');
            });
            $('#vehicle-manufacturer_model_id').trigger('change');

          },
          error: function(error){
            console.log(error);
          }
        });
    });

    var parent_id =  $('#vehicle-manufacturer_id').val()
    $.ajax({
      url: '/vehicle/default/manufacturer-model?id='+ parent_id,
      type: 'get',
      success: function(data){

        $('#vehicle-manufacturer_model_id').html(null).trigger('change');
        $('#vehicle-manufacturer_model_id').val(null).trigger('change');
        $.each(data, function (i,e){
            var newOption = new Option(e.title, e.id, true, false);
            $("#vehicle-manufacturer_model_id").append(newOption).trigger('change');
        });
        $('#vehicle-manufacturer_model_id').val("<?= $model->manufacturer_model_id ?>");
        $('#vehicle-manufacturer_model_id').trigger('change');

      },
      error: function(error){
        alert(error);
      }
    });
</script>
