<?php

use yeesoft\helpers\Html;
use yii\widgets\DetailView;

/* @var $this yii\web\View */
/* @var $model backend\modules\vehicle\models\Vehicle */

$this->title = $model->title;
$this->params['breadcrumbs'][] = ['label' => 'Vehicles', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="vehicle-view">

    <h3 class="lte-hide-title"><?= Html::encode($this->title) ?></h3>

    <div class="panel panel-default">
        <div class="panel-body">

            <p>
                <?= Html::a('Edit', ['/vehicle/default/update', 'id' => $model->id],
                    ['class' => 'btn btn-sm btn-primary'])
                ?>
                <?= Html::a('Delete', ['/vehicle/default/delete', 'id' => $model->id],
                    [
                        'class' => 'btn btn-sm btn-default',
                        'data' => [
                            'confirm' => Yii::t('yii', 'Are you sure you want to delete this item?'),
                            'method' => 'post',
                        ],
                    ])
                ?>
                <?= Html::a(Yii::t('yee', 'Add New'), ['/vehicle/default/create'],
                    ['class' => 'btn btn-sm btn-primary pull-right'])
                ?>
            </p>


            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    'slug',
//                    'status',
//                    'owner_id',
//                    'price',
//                    'model_year',
//                    'odometer_km',
//                    'odometer_mile',
//                    'color_id',
//                    'interior_color_id',
//                    'front_left_status',
//                    'front_right_status',
//                    'back_left_status',
//                    'back_right_status',
//                    'body_type_id',
//                    'cylinders_id',
//                    'capacity',
//                    'engine_id',
//                    'power',
//                    'rim_size',
//                    'transmission_id',
//                    'drive_id',
//                    'video_file',
//                    'manufacturer_id',
//                    'created_at',
//                    'updated_at',
//                    'created_by',
//                    'updated_by',
                ],
            ])
            ?>

            <table role="presentation" class="table table-striped">
                <tbody class="files">
                <?php
                foreach ($model->vehicleImages as $img):
                    /* @var $img \backend\modules\places\models\PlaceImages */
                    $imgRefObj = \yeesoft\media\models\Media::findOne(['url' => $img->path]);
                    if (!$imgRefObj) continue;
                    ?>

                    <tr class="template-download fade in">
                        <td>
                            <span class="preview">

                                    <a href="<?= $img->path ?>" data-gallery="">
                                       <?= Html::img(\common\helpers\Utility::getThumb($img->path)->getDefaultThumbUrl()) ?>
                                    </a>

                            </span>
                        </td>

                        <td>

                            <?php echo Html::radio('vehicleImageFront', ($img->on_front ? 1 : 0), ['class' => 'vehicleImageFront', 'value' => $img->id]) ?>

                        </td>
                        <td>

                            <?php echo Html::a('Delete', ["/vehicle/default/delete-image", 'id' => $model->id, 'path' => $img->path], ['data-method' => 'POST', 'class' => 'btn btn-danger delete']) ?>

                        </td>
                    </tr>


                <?php endforeach; ?>

                <?php
                foreach ($model->vehicle360Images as $img):
                    /* @var $img \backend\modules\places\models\PlaceImages */
                    $imgRefObj = \yeesoft\media\models\Media::findOne(['url' => $img->path]);
                    if (!$imgRefObj) continue;
                    ?>

                    <tr class="template-download fade in">
                        <td>
                            <span class="preview">

                                    <a href="<?= $img->path ?>" data-gallery="">
                                       <?= Html::img(\common\helpers\Utility::getThumb($img->path)->getDefaultThumbUrl()) ?>
                                    </a>

                            </span>
                        </td>
                        <td>

                            <?php echo Html::a('Delete', ["/vehicle/default/delete-image", 'id' => $model->id, 'path' => $img->path], ['data-method' => 'POST', 'class' => 'btn btn-danger delete']) ?>

                        </td>
                    </tr>


                <?php endforeach; ?>
                </tbody>
            </table>

            <br>
            <hr>
            <hr>
            <br>
            <h2>Attachments File</h2>
            <table role="presentation" class="table table-striped">
                <tbody class="files">
                <?php
                foreach ($model->attachmentsFiles as $file):
                    /* @var $file \backend\modules\places\models\PlaceImages */
                    $imgRefObj = \yeesoft\media\models\Media::findOne(['url' => $file->path]);
                    if (!$imgRefObj) continue;
                    ?>

                    <tr class="template-download fade in">
                        <td>
                            <span class="preview">

                                    <a href="<?= $file->path ?>" data-gallery="">
                                        <?= basename($file->path) ?>
                                    </a>

                            </span>
                        </td>

                        <td>

                            <?php echo Html::a('Delete', ["/vehicle/default/delete-image", 'id' => $model->id, 'path' => $file->path], ['data-method' => 'POST', 'class' => 'btn btn-danger delete']) ?>

                        </td>
                    </tr>


                <?php endforeach; ?>

                </tbody>
            </table>

        </div>
    </div>

</div>



<?php


$js = <<<JS
    
    
    $(".vehicleImageFront").on('change', function(e) {
        // Access to full data
        var model_id =  {$model->id};
        var img_id =  $(this).val();
        $.ajax({       
          url: '/vehicle/default/set-front-image',
          data:{model_id:model_id,image_id:img_id},
          type: 'POST',
          success: function(data){ 

          },
          error: function(error){
          }
        });
    });


    
JS;

$this->registerJs($js, yii\web\View::POS_END);
?>