<?php

use backend\assets\AppAsset;
use yeesoft\assets\MetisMenuAsset;
use yeesoft\assets\YeeAsset;
use yeesoft\models\Menu;
use yeesoft\widgets\LanguageSelector;
use yeesoft\widgets\Nav;
use yii\bootstrap\NavBar;
use yii\helpers\Html;
use yii\widgets\Breadcrumbs;
use yii2assets\printthis\PrintThis;

/* @var $this \yii\web\View */
/* @var $content string */

AppAsset::register($this);
$assetBundle = YeeAsset::register($this);
MetisMenuAsset::register($this);
?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="<?= Yii::$app->language ?>">
<head>
    <meta charset="<?= Yii::$app->charset ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <?= Html::csrfMetaTags() ?>
    <title><?= Html::encode($this->title) ?></title>
    <?php $this->head() ?>
</head>
<body>
<?php $this->beginBody() ?>
<div class="wrap">

    <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">

        <?php
        $logo = $assetBundle->baseUrl . '/images/yee-logo.png';
        NavBar::begin([
            'brandLabel' => Html::img($logo, ['class' => 'yee-logo']),
            'brandUrl' => Yii::$app->homeUrl,
            'options' => [
                'class' => 'navbar-inverse navbar-static-top',
                'style' => 'margin-bottom: 0'
            ],
            'innerContainerOptions' => [
                'class' => 'container-fluid'
            ]
        ]);

        $menuItems = [
            ['label' => str_replace('http://', '', Yii::$app->urlManager->hostInfo), 'url' => Yii::$app->urlManager->hostInfo],
        ];

        if (Yii::$app->user->isGuest) {
            $menuItems[] = ['label' => Yii::t('yee', 'Login'), 'url' => ['/auth/login']];
        } else {
            $menuItems[] = [
                'label' => Yii::t('yee', 'Logout {username}', ['username' => Yii::$app->user->identity->username]),
                'url' => ['/site/logout'],
                'linkOptions' => ['data-method' => 'post']
            ];
        }

        echo Nav::widget([
            'encodeLabels' => false,
            'options' => ['class' => 'navbar-nav navbar-right'],
            'items' => $menuItems,
        ]);

        echo LanguageSelector::widget(['display' => 'label', 'view' => 'pills']);

        NavBar::end();
        ?>

        <!-- SIDEBAR NAV -->
        <div class="navbar-default sidebar metismenu" role="navigation">
            <?= Nav::widget([
                'encodeLabels' => false,
                'dropDownCaret' => '<span class="arrow"></span>',
                'options' => [
                    ['class' => 'nav side-menu'],
                    ['class' => 'nav nav-second-level'],
                    ['class' => 'nav nav-third-level']
                ],
                'items' => Menu::getMenuItems('admin-menu'),
            ]) ?>
        </div>
        <!-- !SIDEBAR NAV -->
    </nav>

    <div id="page-wrapper">
        <div class="container-fluid">
            <div class="row">
                <div class="col-lg-12">
                    <?= Breadcrumbs::widget(['links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : []]) ?>

                    <?php if (Yii::$app->session->hasFlash('crudMessage')): ?>
                        <div class="alert alert-info alert-dismissible alert-crud" role="alert">
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                            <?= Yii::$app->session->getFlash('crudMessage') ?>
                        </div>
                    <?php endif; ?>

                    <div class="pull-right">
                        <?php
                        try {
                            echo PrintThis::widget([
                                'htmlOptions' => [
                                    'id' => 'Print-Me',
                                    'btnClass' => 'btn btn-print',
                                    'btnId' => 'btnPrintThis',
                                    'btnText' => 'Print',
                                    'btnIcon' => 'fa fa-print'
                                ],
                                'options' => [
                                    'debug' => false,
                                    'importCSS' => true,
                                    'importStyle' => false,
                                    //'loadCSS' => "http://kinzyiiportal.local:8089/scss",
                                    'pageTitle' => "",
                                    'removeInline' => false,
                                    'printDelay' => 200,
                                    'header' => null,
                                    'formValues' => true,
                                ]
                            ]);
                        } catch (Exception $e) {
                            var_dump($e->getMessage());
                        }
                        ?>
                    </div>
                    <div id="Print-Me">
                        <?= $content ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

</div>

<?php $this->endBody() ?>
</body>
</html>
<?php $this->endPage() ?>
