<?php

namespace common\helpers;
use Yii;
use Facebook\Facebook;

class FacebookManager
{
    /**
     * getFacebookUserData
     * @Param $data array ["accessToken"=>"FACEBOOK_USER_ACCESS_TOKEN"]
     * @Return array ["result"=>Boolean,"message"=>String,"data"=>array()]
     */
    public static function getFacebookUserData($data=array()){
        $social = Yii::$app->getModule('social');
        if(empty($data["accessToken"]))
            return ["result"=>false,"message"=>"Access token is required","data"=>[]];


        $fb = new Facebook([
            'app_id' => $social->facebook['appId'],
            'app_secret' => $social->facebook['secret'],
            'default_graph_version' => 'v2.10'
        ]);
        try {
            $response = $fb->get('/me?fields=id,name,email', $data["accessToken"]);
        } catch(\Facebook\Exceptions\FacebookResponseException $e) {
            // When Graph returns an error
            return ["result"=>false,"message"=>$e->getMessage(),"data"=>[]];
        } catch(\Facebook\Exceptions\FacebookSDKException $e) {
            // When validation fails or other local issues
            return ["result"=>false,"message"=>"Facebook service is down","data"=>[]];
        }

        $facebookResponse = $response->getGraphUser();
        $responseData=[
            "email"=>$facebookResponse->getEmail(),
            "customerName"=>$facebookResponse->getName(),
            "customerId"=>$facebookResponse->getId(),
        ];
        return ["result"=>true,"message"=>"","data"=>$responseData];
    }
    public static function split_name($name)
    {
        $name = trim($name);
        $nameExploded = explode(' ', $name);
        $first_name = (!empty($nameExploded[0])) ? $nameExploded[0] : '';
        $last_name = (!empty($nameExploded[1])) ? $nameExploded[1] : '';
        return array($first_name, $last_name);
    }
}
