<?php


namespace common\models;

use Yii;
use yii\helpers\Url;

/**
 * This is the model class for table "dropdown_list".
 *
 * @property int $id
 * @property string $slug
 * @property string|null $icon
 * @property string|null $color_code
 * @property int $status 0-pending,1-published
 * @property int|null $published_at
 * @property int|null $created_at
 * @property int|null $updated_at
 * @property int|null $created_by
 * @property int|null $updated_by
 * @property string $category
 * @property int|null $parent_id
 * @property int|null $sort_no
 */

class DropdownList extends \yii\db\ActiveRecord
{

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'dropdown_list';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'slug', 'category'], 'required'],
            [['id', 'status', 'published_at', 'created_at', 'updated_at', 'created_by', 'updated_by', 'parent_id', 'sort_no'], 'integer'],
            [['slug', 'icon', 'color_code', 'category'], 'string', 'max' => 255],
            [['id'], 'unique'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'slug' => 'Slug',
            'icon' => 'Icon',
            'color_code' => 'Color Code',
            'status' => 'Status',
            'published_at' => 'Published At',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
            'created_by' => 'Created By',
            'updated_by' => 'Updated By',
            'category' => 'Category',
            'parent_id' => 'Parent ID',
            'sort_no' => 'Sort No',
        ];
    }

    /**
     * Gets query for [[Parent]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getId()
    {
        return $this->hasMany(DropdownListLang::className(), ['parent_id' => 'id']);
    }

    /**
     * @param $field
     * @return string
     */
    public function getSearchUrl($field){
        return Url::toRoute(['site/search?VehicleSearch['.$field.']='.$this->id]);
    }

    /**
     * @return mixed|void|null
     */
    public function getSlugName(){
        /**@var $model DropdownListLang*/
        $model = DropdownListLang::find()->where(['parent_id'=>$this->id,'language'=>Yii::$app->params['short_language']])->one();
        if($model){
            return $model->title;
        }
        return ucwords(str_replace("-"," ",$this->slug));
    }

    /**
     * @return mixed|void|null
     */
    public function getCylinderName(){
        /**@var $model DropdownListLang*/

        $model = DropdownListLang::find()->where(['parent_id'=>$this->id,'language'=>Yii::$app->params['short_language']])->orderBy(['title' => SORT_ASC])->one();

        if($model){
            return $model->title;
        }
        return ucwords(str_replace("-"," ",$this->slug));
    }

    public function getSlugNameWithIcon(){
        $url = Yii::$app->params['icons_image'];
        /**@var $model DropdownListLang*/
        $icon = DropdownList::find()->where(['id' => $this->id])->one();
        $model = DropdownListLang::find()->where(['parent_id'=>$this->id,'language'=>Yii::$app->params['short_language2']])->one();
        if($model){
            if (Yii::$app->params['short_language2'] == Vehicle::ARABIC_LANGUAGE) {
                return  $model->title .'<img class="form-selection-icon ml-2" src="' . $url . $icon->icon . '" width = "22">';
            }else {
                return '<img class="form-selection-icon" src="' . $url . $icon->icon . '" width = "22">' . $model->title;
            }
        }
        return ucwords(str_replace("-"," ",$this->slug));
    }
    public function getSlugNameWithColor(){
        $icon = DropdownList::find()->where(['id' => $this->id])->one();
        $color = $icon->color_code;

        /**@var $model DropdownListLang*/
        $model = DropdownListLang::find()->where(['parent_id'=>$this->id,'language'=>Yii::$app->params['short_language2']])->one();
        if($model){
            if (Yii::$app->params['short_language2'] == Vehicle::ARABIC_LANGUAGE) {

                return $model->title . '<span class="select2-color mr-2 ml-2" style="background-color:' . $icon->color_code . '; width: 20px;height: 20px; display: inline-block; position:relative; top: 3px;"></span>';

            }else{

                return  '<span class="select2-color mr-2" style="background-color:' . $icon->color_code . '; width: 20px;height: 20px; display: inline-block; position:relative; top: 3px;"></span>'. $model->title;

            }
        }
        return ucwords(str_replace("-"," ",$this->slug));
    }
}
