<?php

namespace common\models;

use Yii;

/**
 * This is the model class for table "vehicle_bids".
 *
 * @property int $id
 * @property int|null $user_id
 * @property int|null $vehicle_id
 * @property float|null $bid
 * @property string|null $created_at
 * @property string|null $updated_at
 * @property int|null $created_by
 * @property int|null $updated_by
 *
 * @property User $user
 * @property Vehicle $vehicle
 *
 */
class VehicleBids extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle_bids';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id','bid'], 'required'],
            [['id', 'user_id', 'vehicle_id', 'created_by', 'updated_by'], 'integer'],
            [['bid'], 'number'],
            [['created_at', 'updated_at'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'user_id' => Yii::t('auto','Bidder Name'),
            'vehicle_id' => Yii::t('auto','Vehicle Name'),
            'bid' => Yii::t('auto','Bid Price'),
            'created_at' => Yii::t('auto','Bid Placed At'),
            'updated_at' => 'Updated At',
            'created_by' => 'Created By',
            'updated_by' => 'Updated By',
        ];
    }

    public function getUser()
    {
        return $this->hasOne(Users::className(),['id' => 'user_id']);
    }

    public function getVehicle()
    {
        return $this->hasOne(Vehicle::class,['id' => 'vehicle_id']);
    }

    public function getSoldVehicle()
    {
        $sold_vehicle = Vehicle::find()->where(['is_sold' => Vehicle::IS_SOLD])->all();

        return $sold_vehicle;
    }

    public function getVehicles()
    {
        $vehicles = Vehicle::find()->where(['approved_at' => Vehicle::PUBLISHED])->all();
    }

    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     * @param string $email the target email address
     * @return bool whether the email was sent
     */
    public function sendEmail($email, $user, $listing)
    {


        return Yii::$app->mailer
            ->compose(
                ['html' => 'bid-html', 'text' => 'bid-text'],
                ['model' => $this, 'user' => $user, 'listing' => $listing]
            )
            ->setTo($email)
            ->setFrom([Yii::$app->params['senderEmail'] => Yii::$app->params['senderName']])
            ->setSubject('New Bid on your Listing ' . Yii::$app->name)
            ->send();
    }
}
